@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -212,7 +213,14 @@ mforms::ToolBar *ModelDiagramForm::get_tools_toolbar() {
         else {
           item = mforms::manage(new mforms::ToolBarItem(mforms::ToggleItem));
 
-          item->set_icon(IconManager::get_instance()->get_icon_path(*titem->icon()));
+          std::string iconName = *titem->icon();
+          std::string darkIcon = *titem->darkIcon();
+          if (mforms::App::get()->isDarkModeActive() && !darkIcon.empty()) {
+            item->set_icon(IconManager::get_instance()->get_icon_path(darkIcon));
+          } else {
+            item->set_icon(IconManager::get_instance()->get_icon_path(iconName));
+          }
+
           item->set_name(*titem->accessibilityName());
           item->setInternalName(base::split(*titem->command(), ":").back());
           scoped_connect(item->signal_activated(), std::bind(&ModelDiagramForm::set_tool, this, item->getInternalName()));
