@@ -1,22 +1,28 @@
 /*
- * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
+#include <cairo/cairo.h>
 
 #include "spatial_draw_box.h"
 #include "mforms/box.h"
@@ -26,16 +32,12 @@
 #include "mforms/progressbar.h"
 
 #include "base/log.h"
-#include <cairo.h>
 
 DEFAULT_LOG_DOMAIN("spatial_draw_box");
 
-class ProgressPanel : public mforms::Box
-{
+class ProgressPanel : public mforms::Box {
 public:
-  ProgressPanel(const std::string &title)
-  : mforms::Box(false), _timer(0)
-  {
+  ProgressPanel(const std::string &title) : mforms::Box(false), _timer(0) {
     set_back_color("#eeeeee");
     set_padding(32);
     set_spacing(8);
@@ -47,26 +49,22 @@ public:
     add(&_progress, false, true);
   }
 
-  ~ProgressPanel()
-  {
+  ~ProgressPanel() {
     if (_timer)
       mforms::Utilities::cancel_timeout(_timer);
   }
 
-  void set_progress(const std::string &doing_what, float pct)
-  {
+  void set_progress(const std::string &doing_what, float pct) {
     _label.set_text(doing_what);
     _progress.set_value(pct);
   }
 
-  void start(boost::function<bool (std::string&, float&)> progress_fetcher, float interval)
-  {
+  void start(std::function<bool(std::string &, float &)> progress_fetcher, float interval) {
     _progress_fetcher = progress_fetcher;
-    _timer = mforms::Utilities::add_timeout(interval, boost::bind(&ProgressPanel::update, this));
+    _timer = mforms::Utilities::add_timeout(interval, std::bind(&ProgressPanel::update, this));
   }
 
-  void stop()
-  {
+  void stop() {
     mforms::Utilities::cancel_timeout(_timer);
     _timer = 0;
   }
@@ -76,14 +74,12 @@ private:
   mforms::Label _title;
   mforms::Label _label;
   mforms::ProgressBar _progress;
-  boost::function<bool (std::string&, float&)> _progress_fetcher;
+  std::function<bool(std::string &, float &)> _progress_fetcher;
 
-  bool update()
-  {
+  bool update() {
     std::string what;
     float pct;
-    if (_progress_fetcher(what, pct))
-    {
+    if (_progress_fetcher(what, pct)) {
       _label.set_text(what);
       _progress.set_value(pct);
     }
@@ -92,15 +88,13 @@ private:
   }
 };
 
-
-void *SpatialDrawBox::do_render_layers(void *data)
-{
-  SpatialDrawBox *self = (SpatialDrawBox*)data;
+void *SpatialDrawBox::do_render_layers(void *data) {
+  SpatialDrawBox *self = (SpatialDrawBox *)data;
   {
     base::MutexLock lock(self->_thread_mutex);
     self->render(self->_needs_reprojection);
     if (!self->_quitting)
-      mforms::Utilities::perform_from_main_thread(boost::bind(&SpatialDrawBox::render_done, self));
+      mforms::Utilities::perform_from_main_thread(std::bind(&SpatialDrawBox::render_done, self));
     else
       delete self->_progress;
   }
@@ -108,24 +102,28 @@ void *SpatialDrawBox::do_render_layers(void *data)
   return NULL;
 }
 
-void SpatialDrawBox::render_in_thread(bool reproject)
-{
+void SpatialDrawBox::render_in_thread(bool reproject) { 
+  if (_renderThread != nullptr) {
+    logDebug3("Render thread didn't finish yet, waiting.\n");
+    g_thread_join(_renderThread);
+    _renderThread = nullptr;
+  }
+
   _needs_reprojection = reproject;
-  if (!_rendering && !_layers.empty())
-  {
+  if (!_rendering && !_layers.empty()) {
     _current_layer = NULL;
     _rendering = true;
     _progress = new ProgressPanel("Rendering spatial data, please wait.");
-    _progress->start(boost::bind(&SpatialDrawBox::get_progress, this, _1, _2), 0.2f);
-    base::create_thread(do_render_layers, this);
+    _progress->start(std::bind(&SpatialDrawBox::get_progress, this, std::placeholders::_1, std::placeholders::_2),
+                     0.2f);
+    _renderThread = base::create_thread(do_render_layers, this);
     work_started(_progress, reproject);
 
     set_needs_repaint();
   }
 }
 
-void *SpatialDrawBox::render_done()
-{
+void *SpatialDrawBox::render_done() {
   _progress->stop();
 
   _rendering = false;
@@ -139,8 +137,7 @@ void *SpatialDrawBox::render_done()
   return NULL;
 }
 
-void SpatialDrawBox::render(bool reproject)
-{
+void SpatialDrawBox::render(bool reproject) {
   int width = get_width();
   int height = get_height();
 
@@ -150,10 +147,9 @@ void SpatialDrawBox::render(bool reproject)
   visible_area.MaxLon = _max_lon;
   visible_area.MinLat = _min_lat;
   visible_area.MinLon = _min_lon;
-  //we need to make a fix cause some projections will fail
+  // we need to make a fix cause some projections will fail
 
-  if (_proj == spatial::ProjBonne)
-  {
+  if (_proj == spatial::ProjBonne) {
     if (visible_area.MaxLat > 154.0)
       visible_area.MaxLat = 154.0;
     if (visible_area.MaxLon > 64.0)
@@ -162,9 +158,7 @@ void SpatialDrawBox::render(bool reproject)
       visible_area.MinLat = -154.0;
     if (visible_area.MinLon < -64.0)
       visible_area.MinLon = -64.0;
-  }
-  else
-  {
+  } else {
     if (visible_area.MaxLat > 179.0)
       visible_area.MaxLat = 179.0;
     if (visible_area.MaxLon > 89.0)
@@ -178,23 +172,21 @@ void SpatialDrawBox::render(bool reproject)
   visible_area.height = height;
   visible_area.width = width;
 
-  try
-  {
+  try {
     if (_spatial_reprojector == NULL)
-      _spatial_reprojector = new spatial::Converter(visible_area,
-                                spatial::Projection::get_instance().get_projection(spatial::ProjGeodetic),
-                                spatial::Projection::get_instance().get_projection(_proj));
-  }
-  catch (std::exception &exc)
-  {
-    log_error("SpatialDrawBox::render: %s\n", exc.what());
+      _spatial_reprojector =
+        new spatial::Converter(visible_area, spatial::Projection::get_instance().get_projection(spatial::ProjGeodetic),
+                               spatial::Projection::get_instance().get_projection(_proj));
+  } catch (std::exception &exc) {
+    logError("SpatialDrawBox::render: %s\n", exc.what());
     return;
   }
 
-  _spatial_reprojector->change_projection(visible_area, NULL, spatial::Projection::get_instance().get_projection(_proj));
+  _spatial_reprojector->change_projection(visible_area, NULL,
+                                          spatial::Projection::get_instance().get_projection(_proj));
 
   // TODO lat/long ranges must be adjusted accordingly to account for the aspect ratio of the visible area
-  boost::shared_ptr<mdc::ImageSurface> surface(new mdc::ImageSurface(get_width(), get_height(), CAIRO_FORMAT_ARGB32));
+  std::shared_ptr<mdc::ImageSurface> surface(new mdc::ImageSurface(get_width(), get_height(), CAIRO_FORMAT_ARGB32));
   _cache = surface;
 
   if (_ctx_cache != NULL)
@@ -205,11 +197,10 @@ void SpatialDrawBox::render(bool reproject)
   _current_layer = NULL;
   _current_layer_index = 0;
 
-  if (_zoom_level != 1)
-  {
+  if (_zoom_level != 1) {
     _ctx_cache->translate(base::Point(this->get_width() / 2.0, this->get_height() / 2.0));
     _ctx_cache->scale(base::Point(_zoom_level, _zoom_level));
-    _ctx_cache->translate(base::Point(- this->get_width() / 2.0, - this->get_height() / 2.0));
+    _ctx_cache->translate(base::Point(-this->get_width() / 2.0, -this->get_height() / 2.0));
   }
 
   _ctx_cache->translate(base::Point(_offset_x, _offset_y));
@@ -222,18 +213,15 @@ void SpatialDrawBox::render(bool reproject)
   int i = 0;
 
   base::MutexLock lock(_layer_mutex);
-  for (std::deque<spatial::Layer*>::iterator it = _layers.begin(); it != _layers.end() && !_quitting; ++it, ++i)
-  {
-    _current_work = base::strfmt("Rendering %i objects in layer %i...", (int)(*it)->size(), i+1);
+  for (std::deque<spatial::Layer *>::iterator it = _layers.begin(); it != _layers.end() && !_quitting; ++it, ++i) {
+    _current_work = base::strfmt("Rendering %i objects in layer %i...", (int)(*it)->size(), i + 1);
 
     _current_layer_index = i;
     _current_layer = *it;
-    if (!(*it)->hidden())
-    {
+    if (!(*it)->hidden()) {
       if (reproject)
         (*it)->render(_spatial_reprojector);
       (*it)->repaint(*_ctx_cache, _zoom_level, base::Rect());
-
     }
   }
 
@@ -241,17 +229,14 @@ void SpatialDrawBox::render(bool reproject)
     _needs_reprojection = false;
 }
 
-
-bool SpatialDrawBox::get_progress(std::string &action, float &pct)
-{
+bool SpatialDrawBox::get_progress(std::string &action, float &pct) {
   bool changed = false;
   _progress_mutex.lock();
   float current_progress = (float)_current_layer_index / _layers.size();
   if (_current_layer)
     current_progress += (1.0f / _layers.size()) * _current_layer->query_render_progress();
 
-  if (pct != current_progress || action != _current_work)
-  {
+  if (pct != current_progress || action != _current_work) {
     changed = true;
     action = _current_work;
     pct = current_progress;
@@ -260,13 +245,22 @@ bool SpatialDrawBox::get_progress(std::string &action, float &pct)
   return changed;
 }
 
-
 SpatialDrawBox::SpatialDrawBox()
-: _background_layer(NULL), _last_autozoom_layer(0),
-_proj(spatial::ProjRobinson), _ctx_cache(NULL), _spatial_reprojector(NULL),
-_zoom_level(1.0), _offset_x(0), _offset_y(0), _ready(false), _dragging(false),
-_rendering(false), _quitting(false), _needs_reprojection(true), _select_pending(false), _selecting(false)
-{
+  : _background_layer(NULL),
+    _last_autozoom_layer(0),
+    _proj(spatial::ProjRobinson),
+    _ctx_cache(NULL),
+    _spatial_reprojector(NULL),
+    _zoom_level(1.0),
+    _offset_x(0),
+    _offset_y(0),
+    _ready(false),
+    _dragging(false),
+    _rendering(false),
+    _quitting(false),
+    _needs_reprojection(true),
+    _select_pending(false),
+    _selecting(false) {
   _displaying_restricted = false;
   _min_lat = -179;
   _max_lat = 179;
@@ -275,11 +269,16 @@ _rendering(false), _quitting(false), _needs_reprojection(true), _select_pending(
 
   _current_layer = NULL;
   _progress = NULL;
+  _renderThread = nullptr;
 }
 
-SpatialDrawBox::~SpatialDrawBox()
-{
+SpatialDrawBox::~SpatialDrawBox() {
   _quitting = true;
+  if (_renderThread != nullptr) {
+    logDebug3("Waiting for render thread to finish.\n");
+    g_thread_join(_renderThread);
+    _renderThread = nullptr;
+  }
   clear();
   // lock the mutex, so that if the worker is still busy, we'll wait for it
 
@@ -288,8 +287,7 @@ SpatialDrawBox::~SpatialDrawBox()
   _ctx_cache = NULL;
 }
 
-void SpatialDrawBox::set_projection(spatial::ProjectionType proj)
-{
+void SpatialDrawBox::set_projection(spatial::ProjectionType proj) {
   if (_spatial_reprojector)
     _spatial_reprojector->change_projection(NULL, spatial::Projection::get_instance().get_projection(proj));
 
@@ -297,14 +295,12 @@ void SpatialDrawBox::set_projection(spatial::ProjectionType proj)
   invalidate(true);
 }
 
-void SpatialDrawBox::zoom_out()
-{
+void SpatialDrawBox::zoom_out() {
   _zoom_level -= 0.2f;
   if (_zoom_level < 1.0)
     _zoom_level = 1.0;
   bool reproject = false;
-  if (_zoom_level == 1.0 && !_hw_zoom_history.empty())
-  {
+  if (_zoom_level == 1.0 && !_hw_zoom_history.empty()) {
     spatial::Envelope env = _hw_zoom_history.top();
     _hw_zoom_history.pop();
     _min_lat = env.top_left.x;
@@ -318,20 +314,18 @@ void SpatialDrawBox::zoom_out()
   invalidate(reproject);
 }
 
-void SpatialDrawBox::zoom_in()
-{
+void SpatialDrawBox::zoom_in() {
   _zoom_level += 0.2f;
   invalidate();
 }
 
-void SpatialDrawBox::auto_zoom(spatial::LayerId layer_id)
-{
+void SpatialDrawBox::auto_zoom(spatial::LayerId layer_id) {
   if (_layers.empty())
     return;
 
   _last_autozoom_layer = layer_id;
 
-  spatial::Layer* lay = get_layer(layer_id);
+  spatial::Layer *lay = get_layer(layer_id);
   if (lay == NULL)
     return;
 
@@ -344,30 +338,23 @@ void SpatialDrawBox::auto_zoom(spatial::LayerId layer_id)
 
   const double ratio = 2.011235955; // taken from (179 *2) / (89*2) world boundaries
 
-  if (h > w)
-  {
+  if (h > w) {
     env.bottom_right.x = env.top_left.x + (h * ratio);
-    if (env.bottom_right.x > 180 || env.bottom_right.x < -180)
-    {
+    if (env.bottom_right.x > 180 || env.bottom_right.x < -180) {
       env.bottom_right.x = 180;
-      env.top_left.x = env.bottom_right.x - (h*ratio);
+      env.top_left.x = env.bottom_right.x - (h * ratio);
     }
-    if (env.top_left.x > 180 || env.top_left.y < -180)
-    {
+    if (env.top_left.x > 180 || env.top_left.y < -180) {
       env.top_left.x = -180;
-      env.bottom_right.x = env.top_left.x + (h*ratio);
+      env.bottom_right.x = env.top_left.x + (h * ratio);
     }
-  }
-  else
-  {
+  } else {
     env.bottom_right.y = env.top_left.y - (w / ratio);
-    if (env.bottom_right.y < -90 || env.bottom_right.y > 90)
-    {
+    if (env.bottom_right.y < -90 || env.bottom_right.y > 90) {
       env.bottom_right.y = -90;
       env.top_left.y = env.bottom_right.y + (w * ratio);
     }
-    if (env.top_left.y < -90 || env.top_left.y > 90)
-    {
+    if (env.top_left.y < -90 || env.top_left.y > 90) {
       env.top_left.y = 90;
       env.bottom_right.y = env.top_left.y - (w * ratio);
     }
@@ -379,16 +366,12 @@ void SpatialDrawBox::auto_zoom(spatial::LayerId layer_id)
   _displaying_restricted = true;
 }
 
-
-void SpatialDrawBox::center_on(double lat, double lon)
-{
-  //XXX
+void SpatialDrawBox::center_on(double lat, double lon) {
+  // XXX
   invalidate();
 }
 
-
-void SpatialDrawBox::reset_view()
-{
+void SpatialDrawBox::reset_view() {
   clear_pins();
 
   _min_lat = -179;
@@ -400,17 +383,14 @@ void SpatialDrawBox::reset_view()
   _offset_x = 0;
   _offset_y = 0;
 
-  while(!_hw_zoom_history.empty())
+  while (!_hw_zoom_history.empty())
     _hw_zoom_history.pop();
 
   invalidate(_displaying_restricted);
   _displaying_restricted = false;
 }
 
-
-
-void SpatialDrawBox::select_area(bool flag)
-{
+void SpatialDrawBox::select_area(bool flag) {
   if (flag)
     mforms::App::get()->set_status_text("Click and drag to select an area to display.");
   else
@@ -418,79 +398,67 @@ void SpatialDrawBox::select_area(bool flag)
   _select_pending = flag;
 }
 
-
-void SpatialDrawBox::clear()
-{
+void SpatialDrawBox::clear() {
   delete _background_layer;
   _background_layer = NULL;
 
-  for (std::deque<spatial::Layer*>::iterator i = _layers.begin(); i != _layers.end(); ++i)
+  for (std::deque<spatial::Layer *>::iterator i = _layers.begin(); i != _layers.end(); ++i)
     (*i)->interrupt();
 
   base::MutexLock lock(_layer_mutex);
-  for (std::deque<spatial::Layer*>::iterator i = _layers.begin(); i != _layers.end(); ++i)
+  for (std::deque<spatial::Layer *>::iterator i = _layers.begin(); i != _layers.end(); ++i)
     delete *i;
   _layers.clear();
-  if (_spatial_reprojector)
-  {
+  if (_spatial_reprojector) {
     _spatial_reprojector->interrupt();
     delete _spatial_reprojector;
     _spatial_reprojector = NULL;
   }
 }
 
-void SpatialDrawBox::set_background(spatial::Layer *layer)
-{
+void SpatialDrawBox::set_background(spatial::Layer *layer) {
   if (_background_layer)
     delete _background_layer;
   _background_layer = layer;
 }
 
-void SpatialDrawBox::set_context_menu(mforms::ContextMenu *menu)
-{
+void SpatialDrawBox::set_context_menu(mforms::ContextMenu *menu) {
   _menu = menu;
 }
 
-void SpatialDrawBox::add_layer(spatial::Layer *layer)
-{
+void SpatialDrawBox::add_layer(spatial::Layer *layer) {
   base::MutexLock lock(_layer_mutex);
-  layer->set_fill_polygons((bool)get_option("SqlEditor::FillUpPolygons", 1));
+  layer->set_fill_polygons(get_option("SqlEditor::FillUpPolygons", 1) >= 1);
   _layers.push_back(layer);
 }
 
-void SpatialDrawBox::remove_layer(spatial::Layer *layer)
-{
+void SpatialDrawBox::remove_layer(spatial::Layer *layer) {
   base::MutexLock lock(_layer_mutex);
   layer->interrupt();
-  std::deque<spatial::Layer*>::iterator l = std::find(_layers.begin(), _layers.end(), layer);
+  std::deque<spatial::Layer *>::iterator l = std::find(_layers.begin(), _layers.end(), layer);
   if (l != _layers.end())
     _layers.erase(l);
 }
 
-void SpatialDrawBox::change_layer_order(const std::vector<spatial::LayerId> &order)
-{
+void SpatialDrawBox::change_layer_order(const std::vector<spatial::LayerId> &order) {
   base::MutexLock lock(_layer_mutex);
-  std::map<spatial::LayerId, spatial::Layer*> layers;
-  for (std::deque<spatial::Layer*>::iterator it = _layers.begin(); it != _layers.end(); ++it)
+  std::map<spatial::LayerId, spatial::Layer *> layers;
+  for (std::deque<spatial::Layer *>::iterator it = _layers.begin(); it != _layers.end(); ++it)
     layers[(*it)->layer_id()] = *it;
 
   _layers.clear();
-  std::map<spatial::LayerId, spatial::Layer*>::iterator it;
-  for (size_t i = 0; i < order.size(); ++i)
-  {
+  std::map<spatial::LayerId, spatial::Layer *>::iterator it;
+  for (size_t i = 0; i < order.size(); ++i) {
     it = layers.find(order[i]);
     if (it != layers.end())
       _layers.push_back(it->second);
   }
 }
 
-spatial::Layer *SpatialDrawBox::get_layer(spatial::LayerId layer_id)
-{
+spatial::Layer *SpatialDrawBox::get_layer(spatial::LayerId layer_id) {
   base::MutexLock lock(_layer_mutex);
-  for (std::deque<spatial::Layer*>::iterator it = _layers.begin(); it != _layers.end(); ++it)
-  {
-    if ((*it)->layer_id() == layer_id)
-    {
+  for (std::deque<spatial::Layer *>::iterator it = _layers.begin(); it != _layers.end(); ++it) {
+    if ((*it)->layer_id() == layer_id) {
       return *it;
     }
   }
@@ -499,20 +467,14 @@ spatial::Layer *SpatialDrawBox::get_layer(spatial::LayerId layer_id)
   return NULL;
 }
 
-
-void SpatialDrawBox::show_layer(spatial::LayerId layer_id, bool flag)
-{
-  if (layer_id == 1 && _background_layer)
-  {
+void SpatialDrawBox::show_layer(spatial::LayerId layer_id, bool flag) {
+  if (layer_id == 1 && _background_layer) {
     _background_layer->set_show(flag);
     invalidate(true);
-  }
-  else
-  {
+  } else {
     base::MutexLock lock(_layer_mutex);
-    for (std::deque<spatial::Layer*>::iterator i = _layers.begin(); i != _layers.end(); ++i)
-      if ((*i)->layer_id() == layer_id)
-      {
+    for (std::deque<spatial::Layer *>::iterator i = _layers.begin(); i != _layers.end(); ++i)
+      if ((*i)->layer_id() == layer_id) {
         (*i)->set_show(flag);
         invalidate(true);
         return;
@@ -520,87 +482,68 @@ void SpatialDrawBox::show_layer(spatial::LayerId layer_id, bool flag)
   }
 }
 
-void SpatialDrawBox::activate()
-{
-  if (!_ready)
-  {
+void SpatialDrawBox::activate() {
+  if (!_ready) {
     _ready = true;
     invalidate(true);
   }
 }
 
-void SpatialDrawBox::invalidate(bool reproject)
-{
+void SpatialDrawBox::invalidate(bool reproject) {
   if (_ready)
     render_in_thread(reproject);
   set_needs_repaint(); // repaint the grid
 }
 
-bool SpatialDrawBox::mouse_double_click(mforms::MouseButton button, int x, int y)
-{
+bool SpatialDrawBox::mouse_double_click(mforms::MouseButton button, int x, int y) {
   int dx, dy;
   dx = this->get_width() / 2;
   dy = this->get_height() / 2;
-  _offset_x = _initial_offset_x - (x - dx) / _zoom_level;
-  _offset_y = _initial_offset_y - (y - dy) / _zoom_level;
+  _offset_x = (int)(_initial_offset_x - (x - dx) / _zoom_level);
+  _offset_y = (int)(_initial_offset_y - (y - dy) / _zoom_level);
   _dragging = false;
-  invalidate();
   zoom_in();
 
   return false;
 }
 
-bool SpatialDrawBox::mouse_down(mforms::MouseButton button, int x, int y)
-{
-  if (button == mforms::MouseButtonLeft)
-  {
+bool SpatialDrawBox::mouse_down(mforms::MouseButton button, int x, int y) {
+  if (button == mforms::MouseButtonLeft) {
     _initial_offset_x = _offset_x;
     _initial_offset_y = _offset_y;
     _drag_x = x;
     _drag_y = y;
-    if (_select_pending || _selecting)
-    {
+    if (_select_pending || _selecting) {
       _selecting = true;
-//      _select_pending = false;
-    }
-    else
+      //      _select_pending = false;
+    } else
       _dragging = true;
-  }
-  else if (button == mforms::MouseButtonRight)
-  {
+  } else if (button == mforms::MouseButtonRight) {
     double lat = 0, lon = 0;
     screen_to_world(x, y, lat, lon);
     _clicked_coordinates = std::make_pair(lat, lon);
     _right_clicked_point = base::Point(x, y);
 
-    if (_menu)
-    {
-      std::pair<int,int> p = client_to_screen(x, y);
+    if (_menu) {
+      std::pair<int, int> p = client_to_screen(x, y);
       _menu->popup_at(this, base::Point(p.first, p.second));
     }
   }
   return true;
 }
 
-bool SpatialDrawBox::mouse_up(mforms::MouseButton button, int x, int y)
-{
-  if (button == mforms::MouseButtonLeft && _dragging)
-  {
-    if (_drag_x == x && _drag_y == y)
-    {
+bool SpatialDrawBox::mouse_up(mforms::MouseButton button, int x, int y) {
+  if (button == mforms::MouseButtonLeft && _dragging) {
+    if (_drag_x == x && _drag_y == y) {
       // handle feature click
       if (position_clicked_cb)
         position_clicked_cb(base::Point(x, y));
-    }
-    else
-    {
+    } else {
       mouse_move(button, x, y);
       invalidate();
     }
     _dragging = false;
-  }
-  else if (button == mforms::MouseButtonLeft && _selecting)
-  {
+  } else if (button == mforms::MouseButtonLeft && _selecting) {
     restrict_displayed_area(_drag_x, _drag_y, x, y);
     _selecting = false;
     set_needs_repaint();
@@ -612,16 +555,12 @@ bool SpatialDrawBox::mouse_up(mforms::MouseButton button, int x, int y)
   return true;
 }
 
-bool SpatialDrawBox::mouse_move(mforms::MouseButton button, int x, int y)
-{
-  if (_dragging)
-  {
-    _offset_x = _initial_offset_x + (x - _drag_x) / _zoom_level;
-    _offset_y = _initial_offset_y + (y - _drag_y) / _zoom_level;
+bool SpatialDrawBox::mouse_move(mforms::MouseButton button, int x, int y) {
+  if (_dragging) {
+    _offset_x = (int)(_initial_offset_x + (x - _drag_x) / _zoom_level);
+    _offset_y = (int)(_initial_offset_y + (y - _drag_y) / _zoom_level);
     set_needs_repaint();
-  }
-  else if (_selecting)
-  {
+  } else if (_selecting) {
     _select_x = x;
     _select_y = y;
     set_needs_repaint();
@@ -632,18 +571,15 @@ bool SpatialDrawBox::mouse_move(mforms::MouseButton button, int x, int y)
   return true;
 }
 
-int SpatialDrawBox::clicked_row_id()
-{
+int SpatialDrawBox::clicked_row_id() {
   int row_id = -1;
 
   base::Point p(_right_clicked_point.x - _offset_x, _right_clicked_point.y - _offset_y);
   base::MutexLock lock(_layer_mutex);
-  for (std::deque<spatial::Layer*>::iterator it = _layers.begin(); it != _layers.end(); ++it)
-  {
+  for (std::deque<spatial::Layer *>::iterator it = _layers.begin(); it != _layers.end(); ++it) {
     spatial::Feature *feature;
     feature = (*it)->feature_closest(p);
-    if (feature)
-    {
+    if (feature) {
       row_id = feature->row_id();
       break;
     }
@@ -652,17 +588,16 @@ int SpatialDrawBox::clicked_row_id()
   return row_id;
 }
 
-void SpatialDrawBox::restrict_displayed_area(int x1, int y1, int x2, int y2, bool no_invalidate)
-{
+void SpatialDrawBox::restrict_displayed_area(int x1, int y1, int x2, int y2, bool no_invalidate) {
   double lat1, lat2;
   double lon1, lon2;
 
-  if (x1 > x2) std::swap(x1, x2);
-  if (y1 > y2) std::swap(y1, y2);
+  if (x1 > x2)
+    std::swap(x1, x2);
+  if (y1 > y2)
+    std::swap(y1, y2);
 
-  if (screen_to_world(x1, y1, lat1, lon1) &&
-      screen_to_world(x2, y2, lat2, lon2))
-  {
+  if (screen_to_world(x1, y1, lat1, lon1) && screen_to_world(x2, y2, lat2, lon2)) {
     double h = fabs(lat2 - lat1);
 
     double ratio = 2.011235955; // taken from (179 *2) / (89*2) world boundaries
@@ -673,11 +608,11 @@ void SpatialDrawBox::restrict_displayed_area(int x1, int y1, int x2, int y2, boo
     _offset_y = 0;
 
     spatial::Envelope env;
-     env.top_left.x = _min_lat;
-     env.bottom_right.x = _max_lat;
-     env.bottom_right.y = _min_lon;
-     env.top_left.y = _max_lon;
-     _hw_zoom_history.push(env);
+    env.top_left.x = _min_lat;
+    env.bottom_right.x = _max_lat;
+    env.bottom_right.y = _min_lon;
+    env.top_left.y = _max_lon;
+    _hw_zoom_history.push(env);
 
     _min_lat = lon1;
     _max_lat = lon2;
@@ -690,12 +625,10 @@ void SpatialDrawBox::restrict_displayed_area(int x1, int y1, int x2, int y2, boo
   }
 }
 
-void SpatialDrawBox::repaint(cairo_t *crt, int x, int y, int w, int h)
-{
-  boost::shared_ptr<mdc::Surface> cache(_cache);
+void SpatialDrawBox::repaint(cairo_t *crt, int x, int y, int w, int h) {
+  std::shared_ptr<mdc::Surface> cache(_cache);
   mdc::CairoCtx cr(crt);
-  if (cache)
-  {
+  if (cache) {
     cr.set_color(_background_layer && _background_layer->fill() ? _background_layer->color() : base::Color(1, 1, 1));
     cr.paint();
     cr.set_source_surface(cache->get_surface(), 0, 0);
@@ -703,124 +636,99 @@ void SpatialDrawBox::repaint(cairo_t *crt, int x, int y, int w, int h)
       cr.paint_with_alpha(0.4);
     else
       cr.paint();
-  }
-  else if (!_progress)
-  {
-    cr.set_color(_background_layer &&  _background_layer->fill() ? _background_layer->color() : base::Color(1, 1, 1));
+  } else if (!_progress) {
+    cr.set_color(_background_layer && _background_layer->fill() ? _background_layer->color() : base::Color(1, 1, 1));
     cr.paint();
   }
 
-  if (_background_layer && !_background_layer->hidden())
-  {
+  if (_background_layer && !_background_layer->hidden()) {
     cr.save();
-    if (_zoom_level != 1)
-    {
+    if (_zoom_level != 1) {
       cr.translate(base::Point(this->get_width() / 2, this->get_height() / 2));
       cr.scale(base::Point(_zoom_level, _zoom_level));
-      cr.translate(base::Point(- this->get_width() / 2, - this->get_height() / 2));
+      cr.translate(base::Point(-this->get_width() / 2, -this->get_height() / 2));
     }
 
     cr.translate(base::Point(_offset_x, _offset_y));
 
-
     cr.set_line_width(0);
     _background_layer->repaint(cr, _zoom_level, base::Rect());
     cr.restore();
   }
 
-  if (_rendering)
-  {
+  if (_rendering) {
     cr.set_color(base::Color(0, 0, 0));
     cr.move_to(base::Point(10, 20));
     cr.show_text("Repainting...");
-  }
-  else
-  {
-    for (std::vector<Pin>::const_iterator pin = _pins.begin(); pin != _pins.end(); ++pin)
-    {
-      int w, h;
+  } else {
+    for (std::vector<Pin>::const_iterator pin = _pins.begin(); pin != _pins.end(); ++pin) {
       int x, y;
-      if (pin->icon)
-      {
+      if (pin->icon) {
         world_to_screen(pin->lat, pin->lon, x, y);
-        mforms::Utilities::get_icon_size(pin->icon, w, h);
-        mforms::Utilities::paint_icon(cr.get_cr(), pin->icon, x-w/2, y-h+2);
+        base::Size size = mforms::Utilities::getImageSize(pin->icon);
+        mforms::Utilities::paint_icon(cr.get_cr(), pin->icon, x - size.width / 2, y - size.height + 2);
       }
     }
   }
 
-  if (_selecting)
-  {
+  if (_selecting) {
     cr.set_line_width(2);
     cr.set_color(base::Color(0, 0, 0));
-    cr.rectangle(base::Rect(std::min(_drag_x, _select_x), std::min(_drag_y, _select_y),
-                            abs(_select_x-_drag_x), abs(_select_y-_drag_y)));
+    cr.rectangle(base::Rect(std::min(_drag_x, _select_x), std::min(_drag_y, _select_y), abs(_select_x - _drag_x),
+                            abs(_select_y - _drag_y)));
     cr.stroke();
   }
 }
 
-bool SpatialDrawBox::screen_to_world(const int &x, const int &y, double &lat, double &lon)
-{
-  if (_spatial_reprojector)
-  {
-//     TODO check if x, y are inside the world image
-//    if (x >= _offset_x && y >= _offset_y) <- this is not working when we do rectangular zoom
+bool SpatialDrawBox::screen_to_world(const int &x, const int &y, double &lat, double &lon) {
+  if (_spatial_reprojector) {
+    //     TODO check if x, y are inside the world image
+    //    if (x >= _offset_x && y >= _offset_y) <- this is not working when we do rectangular zoom
 
     base::Point p = apply_cairo_transformation(base::Point(x, y));
-    return _spatial_reprojector->to_latlon(p.x, p.y, lat, lon);
-
+    return _spatial_reprojector->to_latlon((int)p.x, (int)p.y, lat, lon);
   }
   return false;
 }
 
-void SpatialDrawBox::world_to_screen(const double &lat, const double &lon, int &x, int &y)
-{
-  if (_spatial_reprojector)
-  {
+void SpatialDrawBox::world_to_screen(const double &lat, const double &lon, int &x, int &y) {
+  if (_spatial_reprojector) {
     _spatial_reprojector->from_latlon(lat, lon, x, y);
 
     base::Point p = unapply_cairo_transformation(base::Point(x, y));
 
-    x = p.x;
-    y = p.y;
+    x = (int)p.x;
+    y = (int)p.y;
   }
 }
 
-void SpatialDrawBox::save_to_png(const std::string &destination)
-{
-  boost::shared_ptr<mdc::ImageSurface> surface(new mdc::ImageSurface(get_width(), get_height(), CAIRO_FORMAT_ARGB32));
+void SpatialDrawBox::save_to_png(const std::string &destination) {
+  std::shared_ptr<mdc::ImageSurface> surface(new mdc::ImageSurface(get_width(), get_height(), CAIRO_FORMAT_ARGB32));
   mdc::CairoCtx ctx(*surface);
   this->repaint(ctx.get_cr(), 0, 0, get_width(), get_height());
   surface->save_to_png(destination);
 }
 
-void SpatialDrawBox::clear_pins()
-{
+void SpatialDrawBox::clear_pins() {
   _pins.clear();
   set_needs_repaint();
 }
 
-base::Point SpatialDrawBox::unapply_cairo_transformation(const base::Point &p) const
-{
+base::Point SpatialDrawBox::unapply_cairo_transformation(const base::Point &p) const {
   double xx = p.x, yy = p.y;
   _ctx_cache->user_to_device(&xx, &yy);
   return base::Point(xx, yy);
 }
 
-base::Point SpatialDrawBox::apply_cairo_transformation(const base::Point &p) const
-{
+base::Point SpatialDrawBox::apply_cairo_transformation(const base::Point &p) const {
   double xx = p.x, yy = p.y;
   _ctx_cache->device_to_user(&xx, &yy);
   return base::Point(xx, yy);
 }
 
-
-void SpatialDrawBox::place_pin(cairo_surface_t *pin, const base::Point &p)
-{
+void SpatialDrawBox::place_pin(cairo_surface_t *pin, const base::Point &p) {
   double lat, lon;
-  screen_to_world(p.x, p.y, lat, lon);
+  screen_to_world((int)p.x, (int)p.y, lat, lon);
   _pins.push_back(Pin(lat, lon, pin));
   set_needs_repaint();
 }
-
-
