@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -18,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <string>
@@ -52,7 +53,6 @@
 #include "grtui/gui_plugin_base.h"
 
 #include "grt_shell_window.h"
-#include "webbrowser_view.h"
 #include "license_view.h"
 
 #include "mforms/appview.h"
@@ -80,7 +80,6 @@ std::shared_ptr<WBContextUI> WBContextUI::get() {
 
 //--------------------------------------------------------------------------------------------------
 
-
 WBContextUI::WBContextUI() : _wb(new WBContext(false)), _command_ui(new CommandUI(_wb)) {
   _shell_window = 0;
   _active_form = 0;
@@ -104,14 +103,50 @@ WBContextUI::WBContextUI() : _wb(new WBContext(false)), _command_ui(new CommandU
 
 //--------------------------------------------------------------------------------------------------
 
-WBContextUI::~WBContextUI() {
-  _wb->do_close_document(true);
+void WBContextUI::cleanUp() {
+  if (_wb != nullptr) {
+    _wb->do_close_document(true);
+  }
   delete _addon_download_window;
+  _addon_download_window = nullptr;
+
   delete _plugin_install_window;
+  _plugin_install_window = nullptr;
 
   delete _shell_window;
+  _shell_window = nullptr;
+
+  if (_wb != nullptr && !_wb->cancel_idle_tasks()) {
+    // Idle tasks are currently being executed. Wait a moment and then try again.
+    g_usleep(static_cast<int>(100000));
+    _wb->cancel_idle_tasks();
+  }
+  
   delete _wb;
+  _wb = nullptr;
+
   delete _command_ui;
+  _command_ui = nullptr;
+
+
+  // home screen should be released by undock operation,
+  // but it will be left in bad state, we have to clear this
+  _home_screen = nullptr;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+void WBContextUI::reinit() {
+  if (_wb == nullptr) {
+    _wb = new WBContext(false);
+    _command_ui = new CommandUI(_wb);
+  }
+
+}
+//--------------------------------------------------------------------------------------------------
+
+WBContextUI::~WBContextUI() {
+  cleanUp();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -330,18 +365,10 @@ PhysicalOverviewBE *WBContextUI::get_physical_overview() {
 //--------------------------------------------------------------------------------------------------
 
 /*
- * Displays the web page given by url either in an internal window or an external browser instance.
+ * Opens the given web page in the system's default browser.
  */
 void WBContextUI::show_web_page(const std::string &url, bool internal_browser) {
-#ifdef WB_USE_INTERNAL_BROWSER
-  if (internal_browser) {
-    WebBrowserView *browser = mforms::manage(new WebBrowserView(this));
-    mforms::App::get()->dock_view(browser, "maintab");
-    browser->set_title(_("Loading web page..."));
-    browser->navigate(url);
-  } else
-#endif
-    mforms::Utilities::open_url(url);
+  mforms::Utilities::open_url(url);
 }
 
 //--------------------------------------------------------------------------------------------------
