@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -18,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <glib/gstdio.h>
@@ -56,6 +57,7 @@
 #include "mforms/home_screen.h"
 #include "mforms/home_screen_connections.h"
 #include "mforms/home_screen_documents.h"
+#include "mforms/menubar.h"
 #include <zip.h>
 
 DEFAULT_LOG_DOMAIN(DOMAIN_WB_CONTEXT_UI);
@@ -275,7 +277,7 @@ void WBContextUI::show_about() {
  */
 
 void WBContextUI::show_home_screen() {
-  if (_home_screen != NULL) {
+  if (_home_screen != nullptr) {
     _home_screen->showSection(0);
     mforms::App::get()->select_view(_home_screen);
     return;
@@ -285,7 +287,7 @@ void WBContextUI::show_home_screen() {
   if (_home_screen == NULL) {
     // The home screen and its content is freed in AppView::close() during undock_view(...).
     _home_screen = mforms::manage(new mforms::HomeScreen, false);
-    _home_screen->set_menubar(_command_ui->create_menubar_for_context(WB_CONTEXT_HOME_GLOBAL));
+    _home_screen->set_menubar(mforms::setReleaseOnAdd(_command_ui->create_menubar_for_context(WB_CONTEXT_HOME_GLOBAL)));
     _home_screen->onHomeScreenAction =
       std::bind(&WBContextUI::handle_home_action, this, std::placeholders::_1, std::placeholders::_2);
     _home_screen->handleContextMenu =
@@ -362,6 +364,7 @@ void WBContextUI::show_home_screen() {
     menu->add_item(_("Delete All Connections..."), "delete_connection_all");
 
     _home_screen->set_menu(menu, HomeMenuConnection);
+    menu->release();
 
     menu = mforms::manage(new mforms::Menu());
     menu->add_item(_("Move To Top"), "move_connection_to_top");
@@ -385,6 +388,7 @@ void WBContextUI::show_home_screen() {
     menu->add_item(_("Delete Group..."), "delete_connection_group");
 
     _home_screen->set_menu(menu, HomeMenuConnectionGroup);
+    menu->release();
 
     menu = mforms::manage(new mforms::Menu());
     menu->add_item(_("Open Model"), "open_model_from_list");
@@ -407,6 +411,7 @@ void WBContextUI::show_home_screen() {
     menu->add_item(_("Remove Model File from List"), "remove_model");
     menu->add_item(_("Clear List"), "remove_model_all");
     _home_screen->set_menu(menu, HomeMenuDocumentModel);
+    menu->release();
 
     menu = mforms::manage(new mforms::Menu());
     menu->add_item(_("Create EER Model from Database"), "model_from_schema");
@@ -426,6 +431,7 @@ void WBContextUI::show_home_screen() {
     }
 
     _home_screen->set_menu(menu, HomeMenuDocumentModelAction);
+    menu->release();
   }
 
   mforms::App::get()->dock_view(_home_screen, "maintab");
@@ -585,6 +591,10 @@ void WBContextUI::handle_home_context_menu(const base::any &object, const std::s
   } else if (action == "delete_connection") {
     db_mgmt_ConnectionRef connection = getConnectionById(object.as<std::string>());
 
+    if (!connection.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     std::string name = connection->name();
     std::string title;
     std::string warning;
@@ -604,21 +614,37 @@ void WBContextUI::handle_home_context_menu(const base::any &object, const std::s
     // with the name of the group. For connections it's the connection ref.
     // Similar for the other move_* actions.
     db_mgmt_ConnectionRef val = getConnectionById(object.as<std::string>());
+    if (!val.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
     bec::move_list_ref_item<db_mgmt_Connection>(connections, val, MoveTop);
     refresh_home_connections(false);
   } else if (action == "move_connection_up") {
     grt::ValueRef val = getConnectionById(object.as<std::string>());
+    if (!val.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
     bec::move_list_ref_item<db_mgmt_Connection>(connections, val, MoveUp);
     refresh_home_connections(false);
   } else if (action == "move_connection_down") {
     db_mgmt_ConnectionRef val = getConnectionById(object.as<std::string>());
+    if (!val.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
     bec::move_list_ref_item<db_mgmt_Connection>(connections, val, MoveDown);
     refresh_home_connections(false);
   } else if (action == "move_connection_to_end") {
     db_mgmt_ConnectionRef val = getConnectionById(object.as<std::string>());
+    if (!val.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     grt::ListRef<db_mgmt_Connection> connections(_wb->get_root()->rdbmsMgmt()->storedConns());
     bec::move_list_ref_item<db_mgmt_Connection>(connections, val, MoveBottom);
     refresh_home_connections(false);
@@ -628,6 +654,10 @@ void WBContextUI::handle_home_context_menu(const base::any &object, const std::s
     // Create the available groups for the movement...
     std::vector<std::string> groups;
     db_mgmt_ConnectionRef val = getConnectionById(object.as<std::string>());
+    if (!val.is_valid()) {
+      logError("Invalid connection has been found during action: %s\n", action.c_str());
+      return;
+    }
     get_groups_for_movement<db_mgmt_Connection>(connections, val, groups);
 
     SelectOptionDialog dialog(_("Move To Group"), _("Pick a group to move the selected connection "
@@ -1054,8 +1084,8 @@ void WBContextUI::refresh_home_connections(bool clear_state) {
     logWarning("Invalid connection detected %s, deleting it\n", (*iterator)->name().c_str());
     remove_connection(*iterator);
   }
-
-  _wb->save_connections();
+  // XXXX TEST PROBLEM
+  // _wb->save_connections();
   _wb->save_instances();
 }
 
