@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/geometry.h"
@@ -40,10 +45,12 @@ using namespace base;
 
 DEFAULT_LOG_DOMAIN("DbConnectPanel");
 
-static const std::string control_name_prefix = "ctrl__";
-
 grt::StringRef DbDriverParam::get_control_name() const {
-  return grt::StringRef(control_name_prefix + (*_inner->name()));
+  return grt::StringRef(_inner->name());
+}
+
+grt::StringRef DbDriverParam::get_accessibility_name() const {
+  return grt::StringRef(_inner->accessibilityName());
 }
 
 DbDriverParam::ParamType DbDriverParam::decode_param_type(std::string type_name, std::string real_type) {
@@ -70,6 +77,8 @@ DbDriverParam::ParamType DbDriverParam::decode_param_type(std::string type_name,
   else if (0 == type_name.compare("enum")) {
     if (real_type == "int")
       result = ptIntEnum;
+    else if (real_type == "unsigned int")
+      result = ptIntOption;
     else
       result = ptEnum;
   } else if (0 == type_name.compare("text"))
@@ -77,7 +86,7 @@ DbDriverParam::ParamType DbDriverParam::decode_param_type(std::string type_name,
   else if (0 == type_name.compare("button"))
     result = ptButton;
   else
-    g_warning("Unknown DB driver parameter type '%s'", type_name.c_str());
+    logWarning("Unknown DB driver parameter type '%s'\n", type_name.c_str());
 
   return result;
 }
@@ -112,6 +121,8 @@ ControlType DbDriverParam::get_control_type() const {
     case DbDriverParam::ptEnum:
     case DbDriverParam::ptIntEnum:
       return ctEnumSelector;
+    case DbDriverParam::ptIntOption:
+      return ctEnumOption;
     case DbDriverParam::ptText:
       return ctText;
     case DbDriverParam::ptButton:
@@ -140,6 +151,7 @@ void DbDriverParam::set_value(const grt::ValueRef &value) {
     case ptInt:
     case ptBoolean:
     case ptTristate:
+    case ptIntOption:
     case ptIntEnum: {
       if (value.type() == grt::IntegerType)
         _value = value;
@@ -198,10 +210,10 @@ std::vector<std::pair<std::string, std::string> > DbDriverParam::get_enum_option
             options.push_back(std::make_pair(s, s));
         }
       } else
-        logWarning("Error calling enum value lookup method %s.%s for DriverParameter %s",
+        logWarning("Error calling enum value lookup method %s.%s for DriverParameter %s\n",
                    _inner->lookupValueModule().c_str(), _inner->lookupValueMethod().c_str(), _inner->name().c_str());
     } else
-      logWarning("Error searching module for enum value lookup method %s.%s for DriverParameter %s",
+      logWarning("Error searching module for enum value lookup method %s.%s for DriverParameter %s\n",
                  _inner->lookupValueModule().c_str(), _inner->lookupValueMethod().c_str(), _inner->name().c_str());
   }
   return options;
@@ -378,7 +390,7 @@ void DbDriverParams::init(
     }
     param_handle = new DbDriverParam(param, stored_conn);
     _collection[_control_name_index.size()] = param_handle;
-    _control_name_index[control_name_prefix + *param->name()] = param_handle;
+    _control_name_index[param->name()] = param_handle;
   }
 
   if (others_option.is_valid()) {
@@ -396,7 +408,7 @@ void DbDriverParams::init(
     }
     param_handle = new DbDriverParam(others_option, grt::StringRef(unknown_options_text));
     _collection[_control_name_index.size()] = param_handle;
-    _control_name_index[control_name_prefix + *others_option->name()] = param_handle;
+    _control_name_index[others_option->name()] = param_handle;
   }
 
   if (trim_schema)
@@ -554,9 +566,6 @@ std::string DbDriverParams::validate() const {
 
 //----------------------------------------------------------------------
 
-// TODO: can this be removed?
-// static const char *DEFAULT_RDBMS_ID= "com.mysql.rdbms.mysql";
-
 DbConnection::DbConnection(const db_mgmt_ManagementRef &mgmt, const db_mgmt_DriverRef &driver, bool skip_schema)
   : _mgmt(mgmt), _active_driver(driver), _skip_schema(skip_schema) {
 }
@@ -640,7 +649,7 @@ void DbConnection::init_dbc_connection(sql::Connection *dbc_conn, const db_mgmt_
       Sql_specifics::Ref sql_specifics = sql_facade->sqlSpecifics();
       sql_specifics->get_connection_startup_script(sql_script);
     }
-    std::auto_ptr<sql::Statement> stmt(dbc_conn->createStatement());
+    std::unique_ptr<sql::Statement> stmt(dbc_conn->createStatement());
     sql::SqlBatchExec sql_batch_exec;
     sql_batch_exec(stmt.get(), sql_script);
   }
@@ -653,24 +662,6 @@ sql::ConnectionWrapper DbConnection::get_dbc_connection() {
     get_connection(),
     std::bind(&DbConnection::init_dbc_connection, this, std::placeholders::_1, std::placeholders::_2));
 
-  /* This is not used by modeling
-  if (dbc_conn.get() != NULL)
-  {
-    if (_active_driver.is_valid() && _active_driver->owner().is_valid() && (_active_driver->owner().id() ==
-  DEFAULT_RDBMS_ID))
-    {
-      // set SQL_MODE variable to be consistent with SQL stored in the model
-      bec::GRTManager *grtm= bec::GRTManager::get();
-      grt::ValueRef sql_mode_value= grtm->get_app_option("SqlMode");
-      if (sql_mode_value.is_valid() && grt::StringRef::can_wrap(sql_mode_value))
-      {
-        std::string sql_mode_string= base::toupper(grt::StringRef::cast_from(sql_mode_value));
-        std::shared_ptr<sql::Statement> stmt(dbc_conn->createStatement());
-        stmt->execute(base::strfmt("SET @DEFAULT_SQL_MODE=@@SQL_MODE, SQL_MODE='%s'", sql_mode_string.c_str()));
-      }
-    }
-  }*/
-
   return dbc_conn;
 }
 
