@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #ifndef _VAR_GRID_MODEL_BE_H_
@@ -68,9 +73,8 @@ public:
   virtual std::string get_column_caption(ColumnId index);
   virtual ColumnType get_column_type(ColumnId column);
   virtual ColumnType get_real_column_type(ColumnId column);
-  virtual int get_column_width_hint(int column) {
-    return 0; /* 0 - no hint */
-  }
+  virtual int get_column_width_hint(int column) { return 0; /* 0 - no hint */ }
+  virtual bool isGeometry(ColumnId);
 
 public:
   virtual bool is_readonly() const {
@@ -88,6 +92,7 @@ public:
   enum ColumnFlags { NeedsQuoteFlag = 1, NotNullFlag = 2 };
 
   typedef std::vector<std::string> Column_names;
+  typedef std::vector<std::string> DBColumn_types;
   typedef std::vector<sqlite::variant_t> Column_types;
   typedef Data::const_iterator Cell_const;
   typedef std::vector<int> Column_flags;
@@ -153,6 +158,7 @@ protected:
                                    //! is incorrectly parsed
   Column_flags _column_flags; // various flags, such as whether value should be quoted and whether it's NOT NULL (ie
                               // numbers vs strings. special values like functions need extra handling)
+  DBColumn_types _dbColumnTypes;
 
   base::RecMutex _data_mutex;
 
