@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "note_figure.h"
@@ -29,12 +34,12 @@ Note::Note(mdc::Layer *layer, FigureEventHub *hub, const model_ObjectRef &self)
   set_accepts_selection(true);
 
   set_border_color(Color(0.5, 0.5, 0.5, 0.2));
-  set_background_color(Color::White());
+  set_background_color(Color::white());
   set_draw_background(true);
 
   _text.set_padding(8, 8);
   _text.set_font(get_view()->get_default_font());
-  _text.set_pen_color(Color::Black());
+  _text.set_pen_color(Color::black());
   _text.set_multi_line(true);
 
   add(&_text, false, false, true);
@@ -95,4 +100,4 @@ void Note::set_allow_manual_resizing(bool flag) {
     _text.set_auto_sizing(true);
     _text.set_allow_shrinking(false);
   }
-}
\ No newline at end of file
+}
