@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -1104,8 +1105,6 @@ void MainForm::lock_gui_becb(bool lock) {
 
 //------------------------------------------------------------------------------
 void MainForm::switch_page(Gtk::Widget *, guint pagenum) {
-  if (_gui_locked)
-    return;
   Gtk::Notebook *note = get_upper_note();
   Gtk::Widget *page = note->get_nth_page(pagenum);
   if (page) {
@@ -1497,7 +1496,7 @@ static std::string get_resource_path(mforms::App *app, const std::string &file)
     return bec::IconManager::get_instance()->get_icon_path(file);
   else if (g_str_has_suffix(file.c_str(), ".txt")) { // This is special handling for txt only on Linux.
     auto parts = base::split(bec::GRTManager::get()->get_basedir(), "/");
-    std::string last = parts.back();
+    std::string last = parts.back() + (wb::WBContextUI::get()->get_wb()->is_commercial() ? "-commercial" : "-community");
     parts.pop_back();
     parts.push_back("doc");
     parts.push_back(last);
