@@ -5,12 +5,13 @@
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -414,6 +415,7 @@ static NSString *extender = @"≫";
 - (instancetype)initWithFrame: (NSRect)frameRect {
   self = [super initWithFrame: frameRect];
   if (self != nil) {
+    self.clipsToBounds = YES;
     // Make editor the default. Object editors rely on this default.
     self.tabStyle = MEditorBottomTabSwitcher;
 
@@ -1901,7 +1903,7 @@ static NSString *extender = @"≫";
         else {
           mBusyTabIndicator = [[NSProgressIndicator alloc] initWithFrame: NSMakeRect(NSMaxX(rect) - 23, 2, 16, 16)];
           mBusyTabIndicator.controlSize = NSControlSizeSmall;
-          mBusyTabIndicator.style = NSProgressIndicatorSpinningStyle;
+          mBusyTabIndicator.style = NSProgressIndicatorStyleSpinning;
           [mBusyTabIndicator setIndeterminate: YES];
           [mBusyTabIndicator startAnimation: nil];
           [self addSubview: mBusyTabIndicator];
