@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "GRTTreeDataSource.h"
@@ -23,26 +28,21 @@
  
 @implementation GRTTreeDataSource
 
-- (instancetype)initWithTreeModel:(bec::TreeModel*)model
+- (instancetype)initWithTreeModel: (bec::TreeModel*)model
 {
-  if ((self = [super init]) != nil)
+  self = [super init];
+  if (self != nil)
   {
-    _tree= model;
-    _hideRootNode= NO;
-    _nodeCache= [[NSMutableDictionary alloc] init];
+    _tree = model;
+    _hideRootNode = NO;
+    _nodeCache = [NSMutableDictionary new];
   }
   return self;
 }
 
-
 - (instancetype)init
 {
-  if ((self = [super init]) != nil)
-  {
-    _hideRootNode= NO;
-    _nodeCache= [[NSMutableDictionary alloc] init];
-  }
-  return self;
+  return [self initWithTreeModel: nil];
 }
 
 
@@ -130,7 +130,7 @@
 
 - (void)outlineViewItemWillExpand:(NSNotification *)notification
 {
-  id item= [notification userInfo][@"NSObject"];
+  id item= notification.userInfo[@"NSObject"];
   if (_tree)
     _tree->expand_node([self nodeIdForItem:item]);
 }
@@ -138,7 +138,7 @@
 
 - (void)outlineViewItemDidCollapse:(NSNotification *)notification
 {
-  id item= [notification userInfo][@"NSObject"];
+  id item= notification.userInfo[@"NSObject"];
   
   if (_tree)
     _tree->collapse_node([self nodeIdForItem:item]);
@@ -156,7 +156,7 @@
 - (id)outlineView:(NSOutlineView *)outlineView objectValueForTableColumn:(NSTableColumn *)tableColumn byItem:(id)item
 {
   std::string strvalue;
-  int column= [[tableColumn identifier] integerValue];
+  int column= tableColumn.identifier.intValue;
 
   if (!_tree || !_tree->get_field([self nodeIdForItem:item], column, strvalue))
     return nil;
@@ -167,7 +167,7 @@
 
 - (void)outlineView:(NSOutlineView *)outlineView setObjectValue:(id)object forTableColumn:(NSTableColumn *)tableColumn byItem:(id)item
 {
-  int column= [[tableColumn identifier] integerValue];
+  int column= tableColumn.identifier.intValue;
   
   if ([object respondsToSelector:@selector(UTF8String)])
     _tree->set_field([self nodeIdForItem:item], column, [object UTF8String]);
@@ -183,7 +183,7 @@
     bec::NodeId node_id= [self nodeIdForItem:item];
     bec::IconId icon_id= 0;
     if (_tree != nil)
-      icon_id= _tree->get_field_icon(node_id, [[tableColumn identifier] integerValue], bec::Icon16);
+      icon_id= _tree->get_field_icon(node_id, tableColumn.identifier.integerValue, bec::Icon16);
     
     NSImage *image= [[GRTIconCache sharedIconCache] imageForIconId:icon_id];
     
@@ -200,8 +200,8 @@
     {
       if (!_normalFont)
       {
-        _normalFont = [NSFont systemFontOfSize: [[cell font] pointSize]];
-        _boldFont = [NSFont boldSystemFontOfSize: [_normalFont pointSize]];
+        _normalFont = [NSFont systemFontOfSize: [cell font].pointSize];
+        _boldFont = [NSFont boldSystemFontOfSize: _normalFont.pointSize];
       }
       
       if (_tree && _tree->is_highlighted(node_id))
@@ -240,11 +240,11 @@ static void restore_expanded_child_nodes(NSMutableSet *mset,
   if ([mset containsObject: prefix])
   {
     [outlineView collapseItem: node];
-    [ds treeModel]->expand_node([ds nodeIdForItem: node]);
+    ds.treeModel->expand_node([ds nodeIdForItem: node]);
     [outlineView expandItem: node];
   }
   
-  for (int c = [ds outlineView:outlineView numberOfChildrenOfItem:node], i = 0; i < c; i++)
+  for (NSInteger c = [ds outlineView:outlineView numberOfChildrenOfItem: node], i = 0; i < c; i++)
   {
     id child = [ds outlineView:outlineView child:i ofItem:node];
     NSString *suffix = [ds outlineView:outlineView objectValueForTableColumn:column byItem:child];
@@ -278,7 +278,7 @@ static void save_expanded_child_nodes(NSMutableSet *mset,
   if ([outlineView isItemExpanded: node])
     [mset addObject: prefix];
   
-  for (int c = [ds outlineView:outlineView numberOfChildrenOfItem:node], i = 0; i < c; i++)
+  for (NSInteger c = [ds outlineView: outlineView numberOfChildrenOfItem: node], i = 0; i < c; i++)
   {
     id child = [ds outlineView:outlineView child:i ofItem:node];
     NSString *suffix = [ds outlineView:outlineView objectValueForTableColumn:column byItem:child];
