@@ -5,12 +5,13 @@
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -108,10 +109,10 @@ Color Color::getSystemColor(SystemColor colorType) {
   Color result;
 
   if (color != nil) {
-    NSColor *rgbColor = [color colorUsingColorSpaceName: NSCalibratedRGBColorSpace];
+    NSColor *rgbColor = [color colorUsingColorSpace: NSColorSpace.genericRGBColorSpace];
     if (rgbColor == nil) {
       // A pattern color probably.
-      rgbColor = [color colorUsingColorSpaceName: NSPatternColorSpace];
+      rgbColor = [color colorUsingType: NSColorTypePattern];
       NSImage *pattern = rgbColor.patternImage;
       if (pattern != nil) {
         NSBitmapImageRep *representation = (NSBitmapImageRep *)pattern.representations[0]; // Usually only has one.
