@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -39,6 +40,7 @@
     mOwner = aBox;
     mOwner->set_data(self);
   }
+  self.clipsToBounds = YES;
   return self;
 }
 
@@ -618,24 +620,6 @@ static void expandVertically(std::vector<ChildEntry> &list, int fraction, bool m
     (*mOwner->signal_resized())();
 }
 
-//----------------------------------------------------------------------------------------------------------------------
-
-#if 0
-- (void)drawRect: (NSRect)rect
-{
-  [[NSColor redColor] set];
-  NSFrameRect([self frame]);
-
-  [[NSColor orangeColor] set];
-  NSFrameRect(NSInsetRect([self frame], 5, 5));
-
-  [[NSColor purpleColor] set];
-  for (id view in [self subviews])
-  {
-    NSFrameRect([view frame]);
-  }
-}
-#endif
 
 //----------------------------------------------------------------------------------------------------------------------
 
