@@ -5,12 +5,13 @@
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -33,11 +34,11 @@
 - (instancetype)initWithObject: (mforms::CheckBox*)aCheckBox square: (BOOL)square {
   self = [super initWithObject: aCheckBox buttonType: mforms::PushButton];
   if (self != nil) {
-    [self setButtonType: square ? NSPushOnPushOffButton : NSSwitchButton];
+    [self setButtonType: square ? NSButtonTypePushOnPushOff : NSButtonTypeSwitch];
     if (square)
-      self.bezelStyle = NSShadowlessSquareBezelStyle;
+      self.bezelStyle = NSBezelStyleShadowlessSquare;
     else
-      self.bezelStyle = NSRegularSquareBezelStyle;
+      self.bezelStyle = NSBezelStyleRegularSquare;
 
     mTopLeftOffset = NSMakePoint(0, 0);
     mBottomRightOffset = NSMakePoint(0, 0);
@@ -75,9 +76,9 @@
 - (nullable NSNumber *)accessibilityValue {
     MFCheckBoxImpl* checkbox = mOwner->get_data();
     short int value = 0;
-    if(checkbox.state == NSOnState)
+    if(checkbox.state == NSControlStateValueOn)
         value = 1;
-    else if (checkbox.state == NSMixedState)
+    else if (checkbox.state == NSControlStateValueMixed)
         value = 2;
     return @(value);
 }
@@ -94,7 +95,7 @@ static void checkbox_set_active(mforms::CheckBox *self, bool flag) {
   MFCheckBoxImpl* checkbox = self->get_data();
 
   if (checkbox != nullptr) {
-    checkbox.state = flag ? NSOnState : NSOffState;
+    checkbox.state = flag ? NSControlStateValueOn : NSControlStateValueOff;
   }
 }
 
@@ -104,7 +105,7 @@ static bool checkbox_get_active(::mforms::CheckBox *self) {
   MFCheckBoxImpl* checkbox = self->get_data();
 
   if (checkbox != nullptr) {
-    return checkbox.state == NSOnState;
+    return checkbox.state == NSControlStateValueOn;
   }
 
   return false;
