@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -24,7 +25,7 @@
 #import "MFPopover.h"
 #import "MFMForms.h"
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @interface PopoverFrameView : NSView {
   NSBezierPath* outline;
@@ -36,7 +37,7 @@
 
 @end
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @implementation PopoverFrameView
 
@@ -54,7 +55,7 @@
 
 @end
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @implementation MFPopover
 
@@ -87,17 +88,19 @@
   return self;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)dealloc {
   [NSObject cancelPreviousPerformRequestsWithTarget: self];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (BOOL)canBecomeKeyWindow {
   return YES;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 /**
  * Resize the frame view to accomodate the content view.
@@ -118,7 +121,7 @@
   [super setContentSize: newFrameSize];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 /**
  * Set the given view as content view, that is, as child of our frame view.
@@ -146,13 +149,13 @@
   [frameView addSubview:mChildContentView];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (NSView*)contentView {
   return mChildContentView;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 #define DEFAULT_PADDING 7 // Padding on all sides.
 
@@ -161,7 +164,7 @@
                     windowFrame.size.width - mPadding.horizontal(), windowFrame.size.height - mPadding.vertical());
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)computeCoordinatesAndPadding: (mforms::StartPosition)position {
   // The base size is the size of the main part, without arrow.
@@ -246,7 +249,7 @@
   [self setFrameOrigin:newLocation];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)computeOutline {
   PopoverFrameView* frameView = super.contentView;
@@ -335,7 +338,7 @@
   [frameView setNeedsDisplay: YES];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 /**
  * Resizes the window to accomodate the content view with the computed padding on each side
@@ -350,7 +353,7 @@
   mChildContentView.frame = NSMakeRect(mPadding.left, mPadding.bottom, mBaseSize.width, mBaseSize.height);
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)show:(NSPoint)location relativePosition: (mforms::StartPosition)position {
   if (location.x < 0 && location.y < 0)
@@ -374,7 +377,8 @@
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
+
 // Tracking area related
 
 - (void)mouseExited:(NSEvent*)theEvent {
@@ -384,7 +388,7 @@
     [super mouseExited: theEvent];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)close {
   [mTrackedView removeTrackingArea: mOwnerTracking];
@@ -398,7 +402,13 @@
                 inModes: @[ NSModalPanelRunLoopMode, NSDefaultRunLoopMode ]];
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityPopoverRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
 
 using namespace mforms;
 
