@@ -5,12 +5,13 @@
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -65,7 +66,7 @@
     [self setHasHorizontalScroller: YES];
     
     self.contentView = [[MFClipView alloc] initWithFrame: NSMakeRect(0, 0, 10, 20)];
-
+    self.clipsToBounds = YES;
     self.drawsBackground = drawBG;
     if (bordered)
       self.borderType = NSLineBorder;
