@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -82,6 +83,7 @@
   self = [super initWithFrame: frame];
   if (self != nil) {
     mOwner = aTabView;
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -99,6 +101,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 
 - (instancetype)initWithObject: (::mforms::TabView *)aTabView tabType: (mforms::TabViewType)tabType {
   self = [super initWithFrame: NSMakeRect(10, 10, 100, 100)];
+  self.clipsToBounds = YES;
   if (self) {
     BOOL tabSwitcherBelow = NO;
     mTabView = [[DraggingTabView alloc] initWithFrame: NSMakeRect(0, 0, 100, 100) owner: aTabView];
