@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -117,7 +118,9 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   if (self) {
     mOwner = item;
     mOwner->set_data(self);
+    self.clipsToBounds = YES;
   }
+  
   return self;
 }
 
@@ -193,7 +196,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     mOwner->set_data(self);
     switch (item->get_type()) {
       case ToggleItem:
-        [self setButtonType: NSToggleButton];
+        [self setButtonType: NSButtonTypeToggle];
         [self.cell setHighlightsBy: NSChangeBackgroundCellMask];
         self.bordered = NO;
         break;
@@ -204,20 +207,20 @@ static NSColor* colorFromHexString(const char* hexcolor) {
         break;
 
       case SegmentedToggleItem:
-        [self setButtonType: NSToggleButton];
+        [self setButtonType: NSButtonTypeToggle];
         self.imagePosition = NSImageOnly;
         [self.cell setHighlightsBy: NSChangeBackgroundCellMask];
         self.bordered = NO;
         break;
 
       default: // ActionItem etc.
-        self.bezelStyle = NSTexturedRoundedBezelStyle;
-        self.buttonType = NSMomentaryPushInButton;
+        self.bezelStyle = NSBezelStyleTexturedRounded;
+        self.buttonType = NSButtonTypeMomentaryPushIn;
         self.bordered = NO;
 
         break;
     }
-
+    self.clipsToBounds = YES;
     self.target = self;
     self.action = @selector(perform:);
     self.title = @"";
@@ -254,7 +257,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
 - (void)perform: (id)sender {
   mOwner->callback();
   if (mToolPicker)
-    self.bordered = self.state == NSOnState;  
+    self.bordered = self.state == NSControlStateValueOn;  
 }
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -262,7 +265,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
 - (void)setState: (NSInteger)value {
   super.state = value;
   if (mToolPicker)
-    self.bordered = value == NSOnState;
+    self.bordered = value == NSControlStateValueOn;
 }
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -296,15 +299,16 @@ static NSColor* colorFromHexString(const char* hexcolor) {
 
   if (!self.alternateImage && mOwner->get_type() == ToggleItem) {
     mToolPicker = YES;
-    [self setButtonType: NSOnOffButton];
+    [self setButtonType: NSButtonTypeOnOff];
     [self setBordered: NO];
-    self.bezelStyle = NSTexturedSquareBezelStyle;
+    self.bezelStyle = NSBezelStyleTexturedSquare;
     [self.cell setBackgroundColor: toolbar.backgroundColor];
 
     if (toolbar.type == mforms::SecondaryToolBar) {
       NSSize tsize = toolbar.frame.size;
       [self setFrameSize: NSMakeSize(tsize.height, tsize.height)];
     }
+    self.clipsToBounds = YES;
   }
 }
 
@@ -367,6 +371,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     }
     else
       self.font = [NSFont systemFontOfSize: [NSFont smallSystemFontSize]];
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -436,6 +441,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     mOwner->set_data(self);
     self.imageFrameStyle = NSImageFrameNone;
     self.imageScaling = NSImageScaleNone;
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -497,6 +503,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     [self.cell setSendsSearchStringImmediately: NO];
     self.target = self;
     self.action = @selector(perform:);
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -556,6 +563,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
   if (self) {
     mOwner = item;
     mOwner->set_data(self);
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -610,6 +618,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     self.action = @selector(perform:);
     self.cell.controlSize = NSControlSizeSmall;
     self.font = [NSFont systemFontOfSize: [NSFont smallSystemFontSize]];
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -676,6 +685,7 @@ static NSColor* colorFromHexString(const char* hexcolor) {
     self = [super initWithFrame: NSMakeRect(0, 0, 100, layoutInfo[type].height)];
 
   if (self) {
+    self.clipsToBounds = YES;
     mOwner = owner;
     mOwner->set_data(self);
     
@@ -1103,15 +1113,15 @@ static bool get_item_enabled(ToolBarItem *item) {
 
 static void set_item_checked(ToolBarItem *item, bool flag) {
   id tbitem = item->get_data();
-  if ([tbitem state] != (flag ? NSOnState : NSOffState))
-    [tbitem setState: flag ? NSOnState : NSOffState];
+  if ([tbitem state] != (flag ? NSControlStateValueOn : NSControlStateValueOff))
+    [tbitem setState: flag ? NSControlStateValueOn : NSControlStateValueOff];
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
 static bool get_item_checked(ToolBarItem *item) {
   id tbitem = item->get_data();
-  return [tbitem state] == NSOnState;
+  return [tbitem state] == NSControlStateValueOn;
 }
 
 //----------------------------------------------------------------------------------------------------------------------
