@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -1059,14 +1060,14 @@ STANDARD_FOCUS_HANDLING(self)                 // Notify backend when getting fir
       NSButtonCell *cell = [[NSButtonCell alloc] init];
       column.dataCell = cell;
       cell.title = @"";
-      [cell setButtonType:NSSwitchButton];
+      [cell setButtonType: NSButtonTypeSwitch];
       break;
     }
     case mforms::TriCheckColumnType: {
       NSButtonCell *cell = [[NSButtonCell alloc] init];
       column.dataCell = cell;
       cell.title = @"";
-      [cell setButtonType:NSSwitchButton];
+      [cell setButtonType: NSButtonTypeSwitch];
       [cell setAllowsMixedState: YES];
       break;
     }
@@ -1085,7 +1086,7 @@ STANDARD_FOCUS_HANDLING(self)                 // Notify backend when getting fir
       NSNumberFormatter *nf = [[NSNumberFormatter alloc] init];
       nf.numberStyle = (NSNumberFormatterStyle)kCFNumberFormatterDecimalStyle;
       [column.dataCell setAlignment: NSTextAlignmentRight];
-      [column.dataCell setFormatter:nf];
+      [column.dataCell setFormatter: nf];
       break;
     }
     case mforms::IntegerColumnType:
@@ -1093,7 +1094,7 @@ STANDARD_FOCUS_HANDLING(self)                 // Notify backend when getting fir
       NSNumberFormatter *nf = [[NSNumberFormatter alloc] init];
       nf.numberStyle = NSNumberFormatterNoStyle;
       [column.dataCell setAlignment: NSTextAlignmentRight];
-      [column.dataCell setFormatter:nf];
+      [column.dataCell setFormatter: nf];
       break;
     }
   }
@@ -1449,9 +1450,9 @@ static void sortChildrenOfNode(MFTreeNodeImpl *node, NSArray *sortDescriptors) {
   // First write a special datatype for row reordering if enabled. This is the preferred type in that case.
   if (mCanReorderRows && items.count == 1) {
     NSNumber *number = @([outlineView rowForItem: items.lastObject]);
-    NSData *data = [NSKeyedArchiver archivedDataWithRootObject: @[ number ]];
+    NSData *data = [NSKeyedArchiver archivedDataWithRootObject: @[ number ] requiringSecureCoding: NO error: nil];
     [pboard declareTypes: @[ RowReorderPasteboardDatatype ] owner: nil];
-    [pboard setData: data forType:RowReorderPasteboardDatatype];
+    [pboard setData: data forType: RowReorderPasteboardDatatype];
   }
 
   mforms::DragDetails details;
@@ -1511,7 +1512,7 @@ static void sortChildrenOfNode(MFTreeNodeImpl *node, NSArray *sortDescriptors) {
     NSData *data = [pb dataForType:RowReorderPasteboardDatatype];
     NSAssert((data != nil), @"Drag flavour was not found.");
 
-    NSArray *indexes = [NSKeyedUnarchiver unarchiveObjectWithData: data];
+    NSArray *indexes = [NSKeyedUnarchiver unarchivedObjectOfClass: [NSArray class] fromData: data error: nil];
     NSInteger oldIndex = [indexes.lastObject integerValue];
 
     // Right now only allow reordering flat lists, not trees.
@@ -1541,7 +1542,7 @@ static void sortChildrenOfNode(MFTreeNodeImpl *node, NSArray *sortDescriptors) {
     NSData *data = [pb dataForType:RowReorderPasteboardDatatype];
     NSAssert((data != nil), @"Drag flavour was not found.");
 
-    NSArray *indexes = [NSKeyedUnarchiver unarchiveObjectWithData: data];
+    NSArray *indexes = [NSKeyedUnarchiver unarchivedObjectOfClass: [NSArray class] fromData: data error: nil];
     NSInteger oldIndex = [indexes.lastObject integerValue];
 
     if (index != oldIndex) {
@@ -2027,6 +2028,16 @@ static int treeview_get_column_width(mforms::TreeView *self, int column) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+static void beginUpdate(mforms::TreeView *self) {
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
+static void endUpdate(mforms::TreeView *self) {
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 void cf_treeview_init() {
   mforms::ControlFactory *f = mforms::ControlFactory::get_instance();
 
@@ -2064,6 +2075,9 @@ void cf_treeview_init() {
   
   f->_treeview_impl.set_column_width = &treeview_set_column_width;
   f->_treeview_impl.get_column_width = &treeview_get_column_width;
+    
+  f->_treeview_impl.BeginUpdate = &beginUpdate;
+  f->_treeview_impl.EndUpdate = &endUpdate;
 }
 
 @end
