@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "../lf_mforms.h"
@@ -132,7 +137,7 @@ void mforms::gtk::ToolBarImpl::insert_item(mforms::ToolBar *toolbar, int index,
   if (index < 0 || index >= size)
     index = -1;
   if (impl && w) {
-    bool expand = item->get_expandable();
+    bool expand = false;
     bool fill = false;
     if (item->get_type() == mforms::ExpanderItem)
       expand = fill = true;
@@ -166,15 +171,12 @@ bool mforms::gtk::ToolBarImpl::create_tool_item(mforms::ToolBarItem *item, ToolB
   Gtk::Widget *w = 0;
   switch (type) {
     case mforms::TextActionItem:
-    case mforms::ActionItem:
-    case mforms::SwitcherItem: {
+    case mforms::ActionItem: {
       Gtk::Button *btn = Gtk::manage(new Gtk::Button());
       btn->set_focus_on_click(false);
       btn->set_border_width(0);
       btn->set_relief(Gtk::RELIEF_NONE);
       btn->signal_clicked().connect(sigc::bind(sigc::ptr_fun(process_ctrl_action), btn, item));
-      if (type == mforms::SwitcherItem)
-        btn->set_always_show_image(true);
       w = btn;
       break;
     }
@@ -331,14 +333,9 @@ void mforms::gtk::ToolBarImpl::set_item_text(mforms::ToolBarItem *item, const st
     case mforms::TextActionItem:
     case mforms::ActionItem:
     case mforms::SegmentedToggleItem:
-    case mforms::ToggleItem:
-    case mforms::SwitcherItem: {
+    case mforms::ToggleItem: {
       Gtk::Button *btn = cast<Gtk::Button *>(item->get_data_ptr());
-      if (type == mforms::SwitcherItem) {
-        btn->set_label(label);
-        btn->get_style_context()->add_class("SwitcherItem");
-      } else
-        btn->add_label(label);
+      btn->add_label(label);
       btn->set_name(label);
       break;
     }
@@ -500,11 +497,8 @@ void mforms::gtk::ToolBarImpl::set_selector_items(ToolBarItem *item, const std::
     Gtk::ComboBoxText *w = cast<Gtk::ComboBoxText *>(item->get_data_ptr());
     if (w) {
       w->set_data("ignore_signal", (void *)1);
-#if ((GTKMM_MAJOR_VERSION == 2 && GTKMM_MINOR_VERSION >= 24) || GTKMM_MAJOR_VERSION > 2)
+
       w->remove_all();
-#else
-      w->clear_items();
-#endif
       const int size = values.size();
       for (int i = 0; i < size; ++i)
         w->append(values[i]);
