@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -41,8 +42,8 @@ namespace mforms {
       static void set_min_size(mforms::View *self, int w, int h);
       static void set_padding(View *self, int, int, int, int);
 
-      static int get_x(mforms::View *self);
-      static int get_y(mforms::View *self);
+      static int get_x(const mforms::View *self);
+      static int get_y(const mforms::View *self);
       static void set_position(mforms::View *self, int x, int y);
       static std::pair<int, int> client_to_screen(View *self, int, int);
       static std::pair<int, int> screen_to_client(View *self, int, int);
