@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -84,10 +85,7 @@ void apply_bounds(CellList % list) {
       newBounds.X = entry->bounds.Left + (entry->bounds.Width - newBounds.Width) / 2;
       newBounds.Y = entry->bounds.Top + (entry->bounds.Height - newBounds.Height) / 2;
 
-      // The WebBrowser class doesn't like being resized via DeferWindowPos, so we do it the straight way.
-      // Also, if DeferWindowPos (or BeginDeferWindowPos for that matter) returned an empty handle
-      // then we need to do the resizing that way for all controls.
-      if (hdwp == 0 || is<System::Windows::Forms::WebBrowser>(entry->control))
+      if (hdwp == 0)
         entry->control->Bounds = newBounds;
       else {
         HDWP new_hdwp = DeferWindowPos(hdwp, (HWND)entry->control->Handle.ToPointer(), 0, newBounds.X, newBounds.Y,
