@@ -1,15 +1,16 @@
-# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
 # as published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
+# This program is designed to work with certain software (including
 # but not limited to OpenSSL) that is licensed under separate terms, as
 # designated in a particular file or component or in included license
 # documentation.  The authors of MySQL hereby grant you an additional
 # permission to link the program and your derivative works with the
-# separately licensed software that they have included with MySQL.
+# separately licensed software that they have either included with
+# the program or referenced in the documentation.
 # This program is distributed in the hope that it will be useful,  but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -46,11 +47,11 @@ class TestGlobalModuleCode(TestCase):
         if 'WB_SUDO_PASSWD' in os.environ:
             self.sudo_pwd = os.environ['WB_SUDO_PASSWD']
         else:
-            print '---> WB_SUDO_PASSWD is not defined, skipping TestGlobalModuleCode Admin Tests'
+            print('---> WB_SUDO_PASSWD is not defined, skipping TestGlobalModuleCode Admin Tests')
     
     def test_reset_sudo_prefix(self):
         target_module.reset_sudo_prefix()
-        self.assertEquals(target_module.default_sudo_prefix, '/usr/bin/sudo -S -p EnterPasswordHere')
+        self.assertEqual(target_module.default_sudo_prefix, '/usr/bin/sudo -S -p EnterPasswordHere')
     
     def test_quote_path(self):
         self.assertEqual(target_module.quote_path("/hello/world"), '"/hello/world"')
@@ -66,43 +67,43 @@ class TestGlobalModuleCode(TestCase):
     def test_wrap_for_sudo(self):
     
         #1) Test passing no command
-        with self.assertRaisesRegexp(Exception, 'Empty command passed to execution routine'):
+        with self.assertRaisesRegex(Exception, 'Empty command passed to execution routine'):
             target_module.wrap_for_sudo("", "")
         
         #2) Test wrapping command for current user, no change should be done
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', '', Users.CURRENT), 'ls -l')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', '', Users.CURRENT), 'ls -l')
         
         #3) Test wrapping command for admin user, the default sudo prefix should be added
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', ''), '/usr/bin/sudo -S -p EnterPasswordHere /bin/bash -c "ls -l"')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', ''), '/usr/bin/sudo -S -p EnterPasswordHere /bin/bash -c "ls -l"')
         
         #4) Test wrapping command for admin user, passing a custom sudo prefix
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', 'sudo'), 'sudo /bin/bash -c "ls -l"')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', 'sudo'), 'sudo /bin/bash -c "ls -l"')
 
         #5) Repeast previous 2 test cases but using a user different than admin or the current user
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', '', 'guest'), '/usr/bin/sudo -u guest -S -p EnterPasswordHere /bin/bash -c "ls -l"')
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', 'sudo', 'guest'), 'sudo -u guest /bin/bash -c "ls -l"')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', '', 'guest'), '/usr/bin/sudo -u guest -S -p EnterPasswordHere /bin/bash -c "ls -l"')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', 'sudo', 'guest'), 'sudo -u guest /bin/bash -c "ls -l"')
         
         #6) Test sudo for a spawned command
-        self.assertEquals(target_module.wrap_for_sudo('ls -l', '', to_spawn=True), '/usr/bin/sudo -S -p EnterPasswordHere /usr/bin/nohup /bin/bash -c "ls -l &"')
+        self.assertEqual(target_module.wrap_for_sudo('ls -l', '', to_spawn=True), '/usr/bin/sudo -S -p EnterPasswordHere /usr/bin/nohup /bin/bash -c "ls -l &"')
 
         
     def test_local_run_cmd_linux(self):
         custom_sudo = '/usr/bin/sudo -S -k -p EnterPasswordHere'
         # Creates a folder as the current user
-        self.assertEquals(target_module.local_run_cmd_linux('mkdir __testing_folder'), 0)
+        self.assertEqual(target_module.local_run_cmd_linux('mkdir __testing_folder'), 0)
         
-        self.assertEquals(target_module.local_run_cmd_linux('rmdir __testing_folder'), 0)
+        self.assertEqual(target_module.local_run_cmd_linux('rmdir __testing_folder'), 0)
 
         # Attempts creating a folder using sudo with the incorrect password
-        with self.assertRaisesRegexp(InvalidPasswordError, 'Incorrect password for sudo'):
-            self.assertEquals(target_module.local_run_cmd_linux('mkdir __testing_admin', Users.ADMIN, sudo_prefix = custom_sudo), 1)
+        with self.assertRaisesRegex(InvalidPasswordError, 'Incorrect password for sudo'):
+            self.assertEqual(target_module.local_run_cmd_linux('mkdir __testing_admin', Users.ADMIN, sudo_prefix = custom_sudo), 1)
             
         if self.sudo_pwd:
             # Creates a folder as the root user
-            self.assertEquals(target_module.local_run_cmd_linux('mkdir __testing_admin', Users.ADMIN, self.sudo_pwd, custom_sudo), 0)
+            self.assertEqual(target_module.local_run_cmd_linux('mkdir __testing_admin', Users.ADMIN, self.sudo_pwd, custom_sudo), 0)
             
             # Deletes both folders
-            self.assertEquals(target_module.local_run_cmd_linux('rmdir __testing_admin', Users.ADMIN, self.sudo_pwd, custom_sudo), 0)
+            self.assertEqual(target_module.local_run_cmd_linux('rmdir __testing_admin', Users.ADMIN, self.sudo_pwd, custom_sudo), 0)
         
 
 class TestProcessOpsLinuxLocal(TestCase):
@@ -118,25 +119,25 @@ class TestProcessOpsLinuxLocal(TestCase):
         if 'WB_SUDO_PASSWD' in os.environ:
             self.sudo_pwd = os.environ['WB_SUDO_PASSWD']
         else:
-            print '---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests'
+            print('---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests')
     
         self.target_class = target_module.ProcessOpsLinuxLocal(sudo_prefix = '/usr/bin/sudo -S -k -p EnterPasswordHere', ssh=None)
         
     def test_exec_cmd(self):
         # Creates a folder as the current user
-        self.assertEquals(self.target_class.exec_cmd('mkdir __testing_folder'), 0)
-        self.assertEquals(self.target_class.exec_cmd('rmdir __testing_folder'), 0)
+        self.assertEqual(self.target_class.exec_cmd('mkdir __testing_folder'), 0)
+        self.assertEqual(self.target_class.exec_cmd('rmdir __testing_folder'), 0)
         
         # Attempts creating a folder using sudo with the incorrect password
-        with self.assertRaisesRegexp(InvalidPasswordError, 'Incorrect password for sudo'):
-            self.assertEquals(self.target_class.exec_cmd('mkdir __testing_admin', Users.ADMIN), 1)
+        with self.assertRaisesRegex(InvalidPasswordError, 'Incorrect password for sudo'):
+            self.assertEqual(self.target_class.exec_cmd('mkdir __testing_admin', Users.ADMIN), 1)
                         
         # Creates a folder as the root user
         if self.sudo_pwd:
-            self.assertEquals(self.target_class.exec_cmd('mkdir __testing_admin', Users.ADMIN, self.sudo_pwd), 0)
+            self.assertEqual(self.target_class.exec_cmd('mkdir __testing_admin', Users.ADMIN, self.sudo_pwd), 0)
             
             # Deletes both folders
-            self.assertEquals(self.target_class.exec_cmd('rmdir __testing_admin', Users.ADMIN, self.sudo_pwd), 0)
+            self.assertEqual(self.target_class.exec_cmd('rmdir __testing_admin', Users.ADMIN, self.sudo_pwd), 0)
 
 
 class TestFileOpsLinuxBase(TestCase):
@@ -152,7 +153,7 @@ class TestFileOpsLinuxBase(TestCase):
         if 'WB_SUDO_PASSWD' in os.environ:
             self.sudo_pwd = os.environ['WB_SUDO_PASSWD']
         else:
-            print '---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests'
+            print('---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests')
     
         self.process_ops = target_module.ProcessOpsLinuxLocal(sudo_prefix = '/usr/bin/sudo -S -k -p EnterPasswordHere', ssh=None)
         self.target_class = target_module.FileOpsLinuxBase(self.process_ops, None, 'linux')
@@ -169,7 +170,7 @@ class TestFileOpsLinuxBase(TestCase):
         
     def test_file_exists(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "file_exists", parameter "filename" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "file_exists", parameter "filename" must be an absolute path'):
             self.target_class.file_exists('sample.txt')
         
         for file in self.test_files:
@@ -188,27 +189,27 @@ class TestFileOpsLinuxBase(TestCase):
 
     def test_get_available_space(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "get_available_space", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "get_available_space", parameter "path" must be an absolute path'):
             self.target_class.get_available_space('folder_name')
         
         for folder in self.test_folders:
             # Gets availalbe space of unexisting folder
-            self.assertEquals(self.target_class.get_available_space(folder), 'Could not determine')
+            self.assertEqual(self.target_class.get_available_space(folder), 'Could not determine')
             
             # Gets availalbe space of existing folder
             self.process_ops.exec_cmd('mkdir "%s"' % folder)
-            self.assertRegexpMatches(self.target_class.get_available_space(folder), '.*of.*available')
+            self.assertRegex(self.target_class.get_available_space(folder), '.*of.*available')
             self.process_ops.exec_cmd('rmdir "%s"' % folder)
         
     def test_get_file_owner(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "get_file_owner", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "get_file_owner", parameter "path" must be an absolute path'):
             self.target_class.get_file_owner('test.txt')
         
         
         for file in self.test_files:
             # Gets availalbe space of unexisting file
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.get_file_owner(file)
 
 
@@ -217,7 +218,7 @@ class TestFileOpsLinuxBase(TestCase):
                 self.process_ops.exec_cmd('touch "%s"' % file, Users.ADMIN, self.sudo_pwd)
                 
                 # Ensures the file_exists
-                self.assertEquals(self.target_class.get_file_owner(file), 'root')
+                self.assertEqual(self.target_class.get_file_owner(file), 'root')
 
                 # Removes the temporary file
                 self.process_ops.exec_cmd('rm "%s"' % file, Users.ADMIN, self.sudo_pwd)
@@ -225,7 +226,7 @@ class TestFileOpsLinuxBase(TestCase):
 
     def test_create_directory(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "create_directory", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "create_directory", parameter "path" must be an absolute path'):
             self.target_class.create_directory('test_folder')
         
         for folder in self.test_folders:
@@ -234,13 +235,13 @@ class TestFileOpsLinuxBase(TestCase):
             self.assertTrue(self.target_class.file_exists(folder + '_1'))
             
             # Attempts creating an existing directory
-            with self.assertRaisesRegexp(Exception, 'cannot create directory.*File exists'):
+            with self.assertRaisesRegex(Exception, 'cannot create directory.*File exists'):
                 self.target_class.create_directory(folder + '_1')        
                 
             self.process_ops.exec_cmd('rmdir "%s_1"' % folder)
 
             # Attempts creating a directory with owned but using the current user
-            with self.assertRaisesRegexp(PermissionDeniedError, 'Cannot set owner of directory'):
+            with self.assertRaisesRegex(PermissionDeniedError, 'Cannot set owner of directory'):
                 self.target_class.create_directory(folder + '_2', with_owner = 'other')        
 
             if self.sudo_pwd:
@@ -254,7 +255,7 @@ class TestFileOpsLinuxBase(TestCase):
 
     def test_create_directory_recursive(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "create_directory_recursive", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "create_directory_recursive", parameter "path" must be an absolute path'):
             self.target_class.create_directory_recursive('test_folder')
             
         for folder in self.test_folders:
@@ -267,7 +268,7 @@ class TestFileOpsLinuxBase(TestCase):
             self.assertTrue(self.target_class.file_exists(os.path.join(folder)))
             
             # Creates a directory tree that aalready exists, nothing is expected to happen
-            with self.assertRaisesRegexp(Exception, 'cannot create directory.*File exists'):
+            with self.assertRaisesRegex(Exception, 'cannot create directory.*File exists'):
                 self.target_class.create_directory_recursive(os.path.join(folder, 'one', 'two', 'three'))
 
             self.process_ops.exec_cmd('rm -R "%s"' % folder)
@@ -275,7 +276,7 @@ class TestFileOpsLinuxBase(TestCase):
         
     def test_remove_directory(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "remove_directory", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "remove_directory", parameter "path" must be an absolute path'):
             self.target_class.remove_directory('test_folder')
         
         for folder in self.test_folders:
@@ -287,12 +288,12 @@ class TestFileOpsLinuxBase(TestCase):
             self.assertFalse(self.target_class.file_exists(folder))
             
             # Attempts creating an existing directory
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.remove_directory(folder)
         
     def test_remove_directory_recursive(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "remove_directory_recursive", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "remove_directory_recursive", parameter "path" must be an absolute path'):
             self.target_class.remove_directory_recursive('test_folder')
         
         for folder in self.test_folders:
@@ -307,12 +308,12 @@ class TestFileOpsLinuxBase(TestCase):
             self.assertFalse(self.target_class.file_exists(folder))
             
             # Attempts creating an existing directory
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.remove_directory_recursive(folder)
             
     def test_delete_file(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "delete_file", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "delete_file", parameter "path" must be an absolute path'):
             self.target_class.delete_file('test.txt')
         
         for file in self.test_files:
@@ -325,13 +326,13 @@ class TestFileOpsLinuxBase(TestCase):
             self.assertFalse(self.target_class.file_exists(file))
             
             # Attempts to delete the file that no longer exists
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.delete_file(file)
 
 
     def test_get_file_content(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "get_file_content", parameter "filename" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "get_file_content", parameter "filename" must be an absolute path'):
             self.target_class.get_file_content('test.txt')
         
         for file in self.test_files:
@@ -339,22 +340,22 @@ class TestFileOpsLinuxBase(TestCase):
             self.process_ops.exec_cmd('echo "1234\n6789" >  "%s"' % file)
             
             # gets the file content
-            self.assertEquals(self.target_class.get_file_content(file), '1234\n6789')
+            self.assertEqual(self.target_class.get_file_content(file), '1234\n6789')
             
             # gets the file content skipping the first line
-            self.assertEquals(self.target_class.get_file_content(file, skip_lines = 1), '6789')
+            self.assertEqual(self.target_class.get_file_content(file, skip_lines = 1), '6789')
 
             # Deletes the file
             self.process_ops.exec_cmd('rm "%s"' % file)
 
             # Attempts to get the content of a file that no longer exists
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.get_file_content(file)
 
 
     def test_check_dir_writable(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "check_dir_writable", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "check_dir_writable", parameter "path" must be an absolute path'):
             self.target_class.check_dir_writable('test_folder')
         
         for folder in self.test_folders:
@@ -376,24 +377,24 @@ class TestFileOpsLinuxBase(TestCase):
                 self.process_ops.exec_cmd('rmdir "%s_2"' % folder, Users.ADMIN, self.sudo_pwd)
             
             # Attempts to check dir writability on unexisting folder
-            with self.assertRaisesRegexp(Exception, 'The path.*does not exist'):
+            with self.assertRaisesRegex(Exception, 'The path.*does not exist'):
                 self.target_class.check_dir_writable(folder)
 
             # Attempts to check dir writability on a file
             self.process_ops.exec_cmd('touch "%s"' % folder)
-            with self.assertRaisesRegexp(Exception, 'The path.*is not a directory'):
+            with self.assertRaisesRegex(Exception, 'The path.*is not a directory'):
                 self.target_class.check_dir_writable(folder)
             self.process_ops.exec_cmd('rm "%s"' % folder)
 
 
     def test_listdir(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "listdir", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "listdir", parameter "path" must be an absolute path'):
             self.target_class.listdir('test_folder')
         
         for folder in self.test_folders:
             # Attempts listing unexisting folder
-            with self.assertRaisesRegexp(Exception, 'cannot access.*No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'cannot access.*No such file or directory'):
                 self.target_class.listdir(folder)
                 
                 
@@ -411,18 +412,18 @@ class TestFileOpsLinuxBase(TestCase):
         
     def test_save_file_content_and_backup(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "save_file_content_and_backup", parameter "filename" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "save_file_content_and_backup", parameter "filename" must be an absolute path'):
             self.target_class.save_file_content_and_backup('test.txt', '12345678')
         
         for folder in self.test_folders:
             # Tries to save a file on an unexisting folder
-            with self.assertRaisesRegexp(OSError, 'The path.*does not exist'):
+            with self.assertRaisesRegex(OSError, 'The path.*does not exist'):
                 self.target_class.save_file_content_and_backup(os.path.join(folder, 'test.txt'), '12345678', '.bak')
                 
             # Tries to save a file on a folder with no write permissions
             if self.sudo_pwd:
                 self.process_ops.exec_cmd('mkdir "%s"' % folder, Users.ADMIN, self.sudo_pwd)
-                with self.assertRaisesRegexp(PermissionDeniedError, 'Cannot write to target folder'):
+                with self.assertRaisesRegex(PermissionDeniedError, 'Cannot write to target folder'):
                     self.target_class.save_file_content_and_backup(os.path.join(folder, 'test.txt'), '12345678', '.bak')
                     
                 self.target_class.save_file_content_and_backup(os.path.join(folder, 'test.txt'), '12345678', '.bak', Users.ADMIN, self.sudo_pwd)
@@ -432,14 +433,14 @@ class TestFileOpsLinuxBase(TestCase):
             # Saves the file on a folder, first time
             self.process_ops.exec_cmd('mkdir "%s"' % folder)
             self.target_class.save_file_content_and_backup(os.path.join(folder, 'test.txt'), '1', '.bak')
-            self.assertEquals(self.target_class.get_file_content(os.path.join(folder, 'test.txt')), '1')
+            self.assertEqual(self.target_class.get_file_content(os.path.join(folder, 'test.txt')), '1')
             self.assertFalse(self.target_class.file_exists(os.path.join(folder, 'test.txt.bak')))
             
 
             # Saves the file on a folder, second time
             self.target_class.save_file_content_and_backup(os.path.join(folder, 'test.txt'), '2', '.bak')
-            self.assertEquals(self.target_class.get_file_content(os.path.join(folder, 'test.txt')), '2')
-            self.assertEquals(self.target_class.get_file_content(os.path.join(folder, 'test.txt.bak')), '1')
+            self.assertEqual(self.target_class.get_file_content(os.path.join(folder, 'test.txt')), '2')
+            self.assertEqual(self.target_class.get_file_content(os.path.join(folder, 'test.txt.bak')), '1')
 
             self.process_ops.exec_cmd('rm -R "%s"' % folder)
         
@@ -458,7 +459,7 @@ class TestFileOpsLocalUnix(TestCase):
         if 'WB_SUDO_PASSWD' in os.environ:
             self.sudo_pwd = os.environ['WB_SUDO_PASSWD']
         else:
-            print '---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests'
+            print('---> WB_SUDO_PASSWD is not defined, skipping TestFileOpsLinuxBase Admin Tests')
     
         self.process_ops = target_module.ProcessOpsLinuxLocal(sudo_prefix = '/usr/bin/sudo -S -k -p EnterPasswordHere', ssh=None)
         self.target_class = target_module.FileOpsLocalUnix(self.process_ops, None, 'linux')
@@ -476,7 +477,7 @@ class TestFileOpsLocalUnix(TestCase):
     
     def test_save_file_content(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "save_file_content", parameter "filename" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "save_file_content", parameter "filename" must be an absolute path'):
             self.target_class.save_file_content('test.txt', '12345678')
     
         for file in self.test_files:
@@ -486,7 +487,7 @@ class TestFileOpsLocalUnix(TestCase):
         
     def test_get_file_content(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "get_file_content", parameter "filename" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "get_file_content", parameter "filename" must be an absolute path'):
             self.target_class.get_file_content('test.txt')
 
         for file in self.test_files:
@@ -494,20 +495,20 @@ class TestFileOpsLocalUnix(TestCase):
             self.target_class.save_file_content(file, "1234\n6789")
             
             # Tests loading the full file
-            self.assertEquals(self.target_class.get_file_content(file), "1234\n6789")
+            self.assertEqual(self.target_class.get_file_content(file), "1234\n6789")
             
             # Tests skipping the first line
-            self.assertEquals(self.target_class.get_file_content(file, skip_lines = 1), "6789")
+            self.assertEqual(self.target_class.get_file_content(file, skip_lines = 1), "6789")
             
             # Tests loading the file as ADMIN
             if self.sudo_pwd:
-                self.assertEquals(self.target_class.get_file_content(file, Users.ADMIN, self.sudo_pwd), "1234\n6789")
+                self.assertEqual(self.target_class.get_file_content(file, Users.ADMIN, self.sudo_pwd), "1234\n6789")
             
             self.process_ops.exec_cmd('rm "%s"' % file)
 
     def test_delete_file(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "delete_file", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "delete_file", parameter "path" must be an absolute path'):
             self.target_class.delete_file('test.txt')
         
         for file in self.test_files:
@@ -525,16 +526,16 @@ class TestFileOpsLocalUnix(TestCase):
         
     def test_listdir(self):
         # Ensures the function requires an absolute path
-        with self.assertRaisesRegexp(ValueError, 'Error on path validation for function "listdir", parameter "path" must be an absolute path'):
+        with self.assertRaisesRegex(ValueError, 'Error on path validation for function "listdir", parameter "path" must be an absolute path'):
             self.target_class.listdir('test_folder')
         
         for folder in self.test_folders:
             # Attempts listing unexisting folder
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.listdir(folder)
                 
             # Attempts listing unexisting folder
-            with self.assertRaisesRegexp(Exception, 'No such file or directory'):
+            with self.assertRaisesRegex(Exception, 'No such file or directory'):
                 self.target_class.listdir(folder)
                 
             # Creates temporary folders
