@@ -1,24 +1,31 @@
-# Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2021, Oracle and/or its affiliates.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is designed to work with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have either included with
+# the program or referenced in the documentation.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+
 
-from wb import DefineModule, wbinputs
-import grt
 import os
 import sys
+from wb import DefineModule, wbinputs
+import grt
+
 
 from mforms import Utilities, newButton, newLabel, newBox
 import mforms
@@ -26,20 +33,17 @@ import mforms
 import wb_admin_main
 import wb_admin_utils
 import wba_ssh_ui
-import wb_admin_ssh
 import wb_admin_control
 from wb_server_control import PasswordHandler
 from wb_server_control import ServerProfile
 from workbench.db_utils import MySQLConnection, MySQLError, escape_sql_string
-from wb_common import OperationCancelledError, InvalidPasswordError, NoDriverInConnection, Users
-from wb_server_management import local_get_cmd_output
+from wb_common import OperationCancelledError, InvalidPasswordError, NoDriverInConnection
 
 from workbench.utils import Version
 from workbench.notifications import NotificationCenter
 
 
-from grt import log_info, log_error, log_warning, log_debug
-_this_file = os.path.basename(__file__)
+from workbench.log import log_info, log_warning, log_error, log_debug, log_debug2
 
 
 # How the Administrator Module Works
@@ -71,7 +75,7 @@ _this_file = os.path.basename(__file__)
 
 
 # define this Python module as a GRT module
-ModuleInfo = DefineModule(name= "WbAdmin", author= "Oracle Corp.", version="2.0")
+ModuleInfo = DefineModule(name="WbAdmin", author="Oracle Corp.", version="2.0")
 
 class DBError(Exception):
     pass
@@ -85,7 +89,7 @@ wba_page_modules = []
 class AdministratorContext:
     """
     An instance of the WBA, associated to a SQL Editor.
-    Thi is created when a GRNSQLEditorOpened notification is received.
+    This is created when a GRNSQLEditorOpened notification is received.
 
     Initially, only the different sections of the WBA are added to the sidebar
     and the GUI itself is not initialized until the user enters each section.
@@ -98,6 +102,8 @@ class AdministratorContext:
         self.server_profile = None
         self.admin_pages = {}
         self.page_instances = {}
+        self.page_titles = {}
+        self.disabled_pages = {}
         self.admin_tab = None
         self.error_box = None
         self.ctrl_be = None
@@ -108,7 +114,7 @@ class AdministratorContext:
 
         self.sidebar.add_on_section_command_callback(self._sidebar_entry_clicked)
 
-        self.sidebar_sections = [("wba_management", "MANAGEMENT", []), ("wba_instance", "INSTANCE", [])]
+        self.sidebar_sections = [("Management", "Management", "MANAGEMENT", []), ("Instance", "Instance", "INSTANCE", []), ("Performance", "Performance", "PERFORMANCE", [])]
 
         self.shown_in_sidebar = False
 
@@ -141,6 +147,7 @@ class AdministratorContext:
         self.admin_access_status = None
         self.page_instances = {}
         self.sidebar.clear_selection()
+        self.error_box = None
 
 
     def handle_reconnect(self):
@@ -163,23 +170,6 @@ class AdministratorContext:
               # Retry
               self.server_profile = ServerProfile(self.connection, self.instance_profile, False)
 
-
-    def _check_server_version(self):
-        version = self.ctrl_be.target_version
-        if version:
-            version = version.majorNumber, version.minorNumber
-            valid_versions = ((4,0), (4,1), (5,0), (5,1), (5,2), (5,4), (5,5), (5,6), (5, 7))
-            if version[:2] not in valid_versions:
-                log_warning(_this_file, "%s: Server version %s is NOT supported\n" % (self.__class__.__name__, str(version)) )
-                Utilities.show_error("Unsupported Server Version", "The version of the server you're trying to connect to is %i.%i, which is not supported by Workbench."%version[:2],
-                                     "Close", "Ignore", "")
-                return False
-            else:
-                log_info(_this_file, "%s: Server version %s is supported\n" % (self.__class__.__name__, str(version)) )
-                return True
-        return None
-
-
     def _acquire_admin_access(self):
         if not self._validate_remote_admin_settings():
             self.admin_access_status = "Remote management settings are invalid"
@@ -190,21 +180,17 @@ class AdministratorContext:
                 self.ctrl_be.acquire_admin_access()
                 mforms.App.get().set_status_text("Management support for target host enabled successfully.")
                 return True
-            except wb_admin_ssh.ConnectionError, exc:
-                self.admin_access_status = "Remote management capabilities are currently unavailable.\nSSH connection could not be established\n\n%s" % str(exc)
-                Utilities.show_error("Error opening SSH connection to server (%s@%s)" % (self.instance_profile.loginInfo["ssh.userName"], self.instance_profile.loginInfo["ssh.hostName"]), str(exc), "OK", "", "")
-                return None
-            except OperationCancelledError, exc:
+            except OperationCancelledError as exc:
                 self.admin_access_status = "Remote management capabilities are currently unavailable.\nSSH connection was cancelled"
                 mforms.App.get().set_status_text("Cancelled SSH connection (%s)"%exc)
                 return None
-            except InvalidPasswordError, exc:
+            except InvalidPasswordError as exc:
                 self.admin_access_status = "Remote management capabilities are currently unavailable.\nCould not acquire management access to the server\n\n%s" % exc
                 if Utilities.show_error("Could not acquire management access for administration", "%s" % exc, "Retry", "Cancel", "") == mforms.ResultOk:
                     continue
                 mforms.App.get().set_status_text("Could not Open WB Admin")
                 return None
-            except Exception, exc:
+            except Exception as exc:
                 import traceback
                 traceback.print_exc()
                 self.admin_access_status = "Remote management capabilities are currently unavailable.\nCould not acquire management access to the server\n\n%s" % exc
@@ -239,7 +225,7 @@ class AdministratorContext:
             return False
 
         def validate_setting(settings, option, norm_cb, msg):
-            if settings.has_key(option):
+            if option in settings:
                 if norm_cb is not None:
                     norm_cb(settings, option)
             else:
@@ -249,7 +235,7 @@ class AdministratorContext:
 
         def norm_to_switch(settings, option):
             value = 0
-            if settings.has_key(option):
+            if option in settings:
                 value = settings[option]
                 if value > 0:
                     value = 1
@@ -259,7 +245,7 @@ class AdministratorContext:
             settings[option] = value
 
         def make_str_existing(settings, option):
-            if not settings.has_key(option):
+            if option not in settings:
                 settings[option] = ""
 
         validate_setting(server_instance.serverInfo, "sys.usesudo", norm_to_switch, None)#"Server profile has no indication of sudo usage")
@@ -270,39 +256,36 @@ class AdministratorContext:
     def _dock_admin_tab(self):
         app = mforms.App.get()
         try:
-            self.ctrl_be = wb_admin_control.WbAdminControl(self.server_profile, connect_sql=True)
+            self.ctrl_be = wb_admin_control.WbAdminControl(self.server_profile, self.editor, connect_sql=True)
             self.ctrl_be.init()
 
             self.admin_tab = wb_admin_main.AdministratorTab(self.ctrl_be, self.server_profile, self, self.editor)
-        except MySQLError, exc:
-            if exc.message:
+        except MySQLError as exc:
+            if str(exc):
                 Utilities.show_error("Error Connecting to MySQL Server (%s)" % exc.location, str(exc), "OK", "", "")
             app.set_status_text("Could not Open WB Admin")
             return None
-        except OperationCancelledError, exc:
+        except OperationCancelledError as exc:
             app.set_status_text("Cancelled (%s)"%exc)
             return None
-        except NoDriverInConnection, exc:
+        except NoDriverInConnection as exc:
             Utilities.show_error('Missing connection driver', str(exc), 'OK', '', '')
             app.set_status_text("Could not Open WB Admin")
             return None
-        except Exception, exc:
+        except Exception as exc:
             import traceback
             traceback.print_exc()
             Utilities.show_error("Error Starting Workbench Administrator", "%s: %s" % (type(exc).__name__, exc), "OK", "", "")
             app.set_status_text("Could not Open WB Admin")
             return None
 
-        if self._check_server_version() is False:
-            app.set_status_text("Unsupported server version for Administration")
-            return None
-
-
         dp = mforms.fromgrt(self.editor.dockingPoint)
         dp.dock_view(self.admin_tab, "", 0)
         dp.select_view(self.admin_tab)
         self.admin_tab.set_title("Administrator")
 
+        return self.admin_tab
+
 
     def become_active_tab(self):
         dp = mforms.fromgrt(self.editor.dockingPoint)
@@ -311,10 +294,22 @@ class AdministratorContext:
 
     def _sidebar_entry_clicked(self, entry_id):
         if entry_id == "configure":
-            grt.modules.Workbench.showInstanceManagerFor(self.editor.connection)
+            openConnectionSettings(self.editor)
         else:
+            if entry_id in self.disabled_pages:
+                Utilities.show_error(self.page_titles[entry_id],
+                                     self.disabled_pages[entry_id],
+                                     "OK", "", "")
+                return
             self.open_into_section(entry_id)
 
+    def refresh_admin_links(self):
+        for ident in list(self.disabled_pages.keys()):
+            if (not self.server_profile or (self.server_profile and not self.server_profile.is_local and not self.server_profile.remote_admin_enabled)):
+                pass
+            else:
+                del self.disabled_pages[ident]
+                self.sidebar.set_section_entry_enabled(ident, True)
 
     def open_into_section(self, entry_id, select_item=False):
         page_class, needs_remote_access = self.admin_pages.get(entry_id, (None, None))
@@ -323,7 +318,8 @@ class AdministratorContext:
 
         # if this is the 1st time opening the WBA, init the main tab and dock it
         if self.admin_tab is None:
-            self._dock_admin_tab()
+            if not self._dock_admin_tab():
+                return
 
         page = self.page_instances.get(entry_id)
         if not page:
@@ -335,8 +331,8 @@ class AdministratorContext:
             self.page_instances[entry_id] = page
             self.admin_tab.add_page(page)
 
-        for sname, stitle, sitems in self.sidebar_sections:
-            for ident, title, icon_path in sitems:
+        for sname, saname, stitle, sitems in self.sidebar_sections:
+            for ident, ianame, title, icon_path in sitems:
                 if ident == entry_id:
                     self.admin_tab.set_content_label("Administration - %s" % title)
                     break
@@ -344,33 +340,48 @@ class AdministratorContext:
         self.admin_tab.select_page(page)
 
 
-    def add_section(self, name, title):
+    def add_section(self, name, accessibilityName, title):
         if not any(x[0] == name for x in self.sidebar_sections):
-            self.sidebar_sections.append((name, title, []))
+            self.sidebar_sections.append((name, accessibilityName, title, []))
 
 
-    def register_page(self, page_class, section_id, title, needs_remote_access = False):
+    def register_page(self, page_class, section_id, title, accessibilityName, needs_remote_access=False):
         if not section_id:
-            section_id = "wba_management" # the default
+            section_id = "Management" # the default
+
+        self.page_titles[page_class.identifier()] = title
 
         self.admin_pages[page_class.identifier()] = (page_class, needs_remote_access)
-        icon_path = page_class.identifier()+".png"
-        for sname, stitle, sitems in self.sidebar_sections:
+        icon_path = page_class.identifier() + ".png"
+        for sname, saname, stitle, sitems in self.sidebar_sections:
             if sname == section_id:
-                sitems.append((page_class.identifier(), title, icon_path))
+                sitems.append((page_class.identifier(), accessibilityName, title, icon_path))
                 break
 
     def show_in_sidebar(self):
         if not self.shown_in_sidebar:
+            if self.editor.serverVersion:
+                server_version = Version.fromgrt(self.editor.serverVersion)
+            else:
+                server_version = None
             self.shown_in_sidebar = True
-            for sname, stitle, sitems in self.sidebar_sections:
-                self.sidebar.add_section(sname, stitle, mforms.TaskSectionShowConfigButton if sname == "wba_instance" else mforms.TaskSectionPlain)
-                for ident, ititle, icon_path in sitems:
-                    self.sidebar.add_section_entry(sname, ident, ititle, icon_path, mforms.TaskEntryLink)
-                    requires_remote_access = self.admin_pages.get(ident, (None, True))[1]
+            self.disabled_pages = {}
+            for sname, saname, stitle, sitems in self.sidebar_sections:
+                flags = mforms.TaskSectionShowConfigButton if sname == "Instance" else mforms.TaskSectionPlain
+
+                self.sidebar.add_section(sname, saname, stitle, flags)
+                for ident, ianame, ititle, icon_path in sitems:
+                    self.sidebar.add_section_entry(sname, ident, ianame, ititle, icon_path, mforms.TaskEntryAlwaysActiveLink)
+                    mod, requires_remote_access = self.admin_pages.get(ident, (None, True))
                     enabled = True
                     if requires_remote_access and (not self.server_profile or (self.server_profile and not self.server_profile.is_local and not self.server_profile.remote_admin_enabled)):
                         enabled = False
+                        self.disabled_pages[ident] = "Feature requires remote host access.\nClick the wrench icon to configure a remote administration method for this connection."
+                    elif getattr(mod, "min_server_version", None):
+                        if server_version and not server_version.is_supported_mysql_version_at_least(*mod.min_server_version):
+                            enabled = False
+                            self.disabled_pages[ident] = "This feature requires MySQL version %s or newer" % ".".join([str(x) for x in mod.min_server_version])
+
                     self.sidebar.set_section_entry_enabled(ident, enabled)
 
             self.sidebar.set_collapse_states(grt.root.wb.options.options.get('Administrator:sidebar_collapsed_sections', ''))
@@ -382,12 +393,14 @@ class AdministratorContext:
 #-------------------------------------------------------------------------------
 
 def attachToSQLEditor(name, sender, args):
-    # this is called when a new SQL Editor tab is created
-    # attach our WBA related things to it
-    context = AdministratorContext(sender)
-    sender.customData["adminContext"] = grt.togrt(context)
-    if not sender.isConnected:
-        mforms.Utilities.add_timeout(0.1, lambda:context.open_into_section("admin_server_status", True))
+    if sender.connection:
+        # this is called when a new SQL Editor tab is created
+        # attach our WBA related things to it
+        context = AdministratorContext(sender)
+        sender.customData["adminContext"] = grt.togrt(context)
+        if sender.isConnected <= 0:
+            ignore = mforms.Utilities.add_timeout(0.1, lambda: context.open_into_section("admin_server_status", True))
+            del ignore
 
 #-------------------------------------------------------------------------------
 def handleReconnect(name, sender, args):
@@ -402,8 +415,8 @@ def initialize():
 
     # register ourselves for when SQL Editor tabs are opened
     nc = NotificationCenter()
-    nc.add_observer(attachToSQLEditor, name = "GRNSQLEditorOpened")
-    nc.add_observer(handleReconnect, name = "GRNSQLEditorReconnected")
+    nc.add_observer(attachToSQLEditor, name="GRNSQLEditorOpened")
+    nc.add_observer(handleReconnect, name="GRNSQLEditorReconnected")
 
     return 1
 
@@ -428,16 +441,16 @@ def autoDetectLocalInstance(connection):
         if not path:
             path = mforms.App.get().get_resource_path("")
             if not path:
-                log_error(_this_file, "Could not find mysql.profiles dir\n")
+                log_error("Could not find mysql.profiles dir\n")
                 return []
             path += "/mysql.profiles"
         version = Version.fromstr(version or "5.6")
-        files = os.listdir(path)
+        files = [f for f in os.listdir(path) if f.endswith(".xml")]
         profiles = []
         matched_profiles = []
         for f in files:
             data = grt.unserialize(os.path.join(path, f))
-            if data.has_key("sys.system") and data["sys.system"] == system:
+            if data and "sys.system" in data and data["sys.system"] == system:
                 profiles.append(data)
                 profile_version = Version.fromstr(data.get("serverVersion"))
                 if version.majorNumber == profile_version.majorNumber or version.minorNumber == profile_version.minorNumber:
@@ -459,7 +472,7 @@ def autoDetectLocalInstance(connection):
                 instance.serverInfo.update(profiles[0])
         instance.serverInfo["windowsAdmin"] = 1 # this forces WMI admin for localhost Windows
     elif sys.platform.lower() == "darwin":
-        profiles = get_profiles_for("MacOS X", version)
+        profiles = get_profiles_for("macOS", version)
         if profiles:
             instance.serverInfo.update(profiles[0])
             possible_paths = [instance.serverInfo.get("sys.config.path"), "/etc/my.cnf", "/etc/mysql/my.cnf"]
@@ -537,6 +550,13 @@ class PasswordExpiredDialog(mforms.Form):
     def __init__(self, conn):
         mforms.Form.__init__(self, None)
         self._conn = conn
+        self.versionstr = conn.parameterValues.get("serverVersion", None)
+        
+        try:
+            self.version = Version.fromstr(self.versionstr)
+        except:
+            self.version = None
+        
         self.set_title("Password Expired")
 
         vbox = mforms.newBox(False)
@@ -564,17 +584,29 @@ class PasswordExpiredDialog(mforms.Form):
         vbox.add(hbox, False, True)
 
         self.old_password = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("Old Password:", True), 0, 1, 0, 1, mforms.HFillFlag)
+        self.old_password.set_name("Old Password")
+        box.add(newLabel("Old Password:", True), 0, 1, 0, 1, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.old_password, 1, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.password = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("New Password:", True), 0, 1, 1, 2, mforms.HFillFlag)
+        self.password.set_name("New Password")
+        box.add(newLabel("New Password:", True), 0, 1, 1, 2, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.password, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.confirm = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("Confirm:", True), 0, 1, 2, 3, mforms.HFillFlag)
+        self.confirm.set_name("Confirm Password")
+        box.add(newLabel("Confirm:", True), 0, 1, 2, 3, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.confirm, 1, 2, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
 
+        self.legacy = mforms.newCheckBox()
+        self.legacy.set_text("This server version is < 5.7")
+        if self.version:
+            self.legacy.set_active(not self.version.is_supported_mysql_version_at_least(5, 7))
+            self.legacy.show(False)
+        else:
+            self.legacy.show(True)
+        vbox.add(self.legacy, mforms.HFillFlag|mforms.VFillFlag)
+
         bbox = newBox(True)
         bbox.set_spacing(8)
         self.ok = newButton()
@@ -588,7 +620,7 @@ class PasswordExpiredDialog(mforms.Form):
 
         self.set_content(vbox)
 
-        self.set_size(500, 260)
+        self.set_size(500, 300)
         self.center()
 
 
@@ -597,33 +629,29 @@ class PasswordExpiredDialog(mforms.Form):
             if self.password.get_string_value() != self.confirm.get_string_value():
                 mforms.Utilities.show_error("Reset Password", "The password and its confirmation do not match. Please try again.", "OK", "", "")
                 return self.run()
+            
+            con = self._conn.shallow_copy()
 
-            con = self._conn
-            old_multi_statements = con.parameterValues.get("CLIENT_MULTI_STATEMENTS")
-            old_script = con.parameterValues.get("preInit")
             con.parameterValues["CLIENT_MULTI_STATEMENTS"] = 1
-            con.parameterValues["preInit"] = "SET PASSWORD = PASSWORD('%s')" % escape_sql_string(self.password.get_string_value())
-
+            if self.legacy.get_active():
+                con.parameterValues["preInit"] = "SET PASSWORD = PASSWORD('%s')" % escape_sql_string(self.password.get_string_value())
+            else:
+                con.parameterValues["preInit"] = "SET PASSWORD = '%s'" % escape_sql_string(self.password.get_string_value())
             retry = False
             result = 1
 
-            c = MySQLConnection(con, password = self.old_password.get_string_value())
+            c = MySQLConnection(con, password=self.old_password.get_string_value())
             # connect to server so that preInitScript will do the password reset work
             try:
+                log_info("About to connecto to MySQL Server to change expired password")
                 c.connect()
-            except MySQLError, e:
+                mforms.Utilities_store_password(c.connect_info.hostIdentifier, c.connect_info.parameterValues.userName, self.password.get_string_value())
+            except MySQLError as e:
                 if mforms.Utilities.show_error("Reset Password", str(e), "Retry", "Cancel", "") == mforms.ResultOk:
                     retry = True
                 result = 0
-          
-            if old_script is not None:
-                con.parameterValues["preInit"] = old_script
-            else:
-                del con.parameterValues["preInit"]
-            if old_multi_statements is not None:
-                con.parameterValues["CLIENT_MULTI_STATEMENTS"] = old_multi_statements
-            else:
-                del con.parameterValues["CLIENT_MULTI_STATEMENTS"]
+            except Exception as e:
+                print("Error handling expired password: %s" % str(e))
 
             if retry:
                 return self.run()
@@ -661,46 +689,47 @@ test_ssh_connection_is_windows = None
 @ModuleInfo.export(grt.STRING, grt.STRING, grt.classes.db_mgmt_Connection, grt.classes.db_mgmt_ServerInstance)
 def testInstanceSettingByName(what, connection, server_instance):
     global test_ssh_connection
-
-    log_debug(_this_file, "Test %s in %s\n" % (what, connection.name))
+    log_debug("Test %s in %s\n" % (what, connection.name))
 
     profile = ServerProfile(connection, server_instance)
-
     if what == "connect_to_host":
         if test_ssh_connection:
             test_ssh_connection = None
 
-        log_info(_this_file, "Instance test: Connecting to %s\n" % profile.ssh_hostname)
+        log_info("Instance test: Connecting to %s\n" % profile.ssh_hostname)
 
         try:
-            test_ssh_connection = wb_admin_control.WbAdminControl(profile, connect_sql=False)
+            test_ssh_connection = wb_admin_control.WbAdminControl(profile, None, connect_sql=False, test_only=True)
             test_ssh_connection.init()
+
             grt.send_info("connected.")
-        except Exception, exc:
+        except Exception as exc:
+            log_error("Exception: %s\n" % str(exc))
             import traceback
-            traceback.print_exc()
+            log_debug2("Backtrace was: ", traceback.format_stack())
             return "ERROR "+str(exc)
         except:
-            print "Unknown error"
             return "ERROR"
 
         try:
             test_ssh_connection.acquire_admin_access()
-        except Exception, exc:
+        except Exception as exc:
+            
+            log_error("Exception: %s\n" % str(exc))
             import traceback
-            traceback.print_exc()
+            log_debug2("Backtrace was: " % traceback.format_stack())
             return "ERROR "+str(exc)
 
         os_info = test_ssh_connection.detect_operating_system_version()
         if os_info:
             os_type, os_name, os_variant, os_version = os_info
-            log_info(_this_file, "Instance test: detected remote OS: %s (%s), %s, %s\n" % (os_info))
+            log_info("Instance test: detected remote OS: %s (%s), %s, %s\n" % (os_info))
 
             # check if the admin access error was because of wrong OS set
             if os_type != profile.target_os:
                 return "ERROR Wrong Remote OS configured for connection. Set to %s, but was detected as %s" % (profile.target_os, os_type)
         else:
-            log_warning(_this_file, "Instance test: could not determine OS version information\n")
+            log_warning("Instance test: could not determine OS version information\n")
 
             return "ERROR Could not determine remote OS details"
 
@@ -716,12 +745,12 @@ def testInstanceSettingByName(what, connection, server_instance):
 
     elif what in ("find_config_file", "check_config_path", "check_config_section"):
         config_file = profile.config_file_path
-        print "Check if %s exists in remote host" % config_file
+        print("Check if %s exists in remote host" % config_file)
         try:
-            if not test_ssh_connection.ssh.file_exists(config_file):
+            if not test_ssh_connection.ssh.fileExists(config_file):
                 return "ERROR File %s doesn't exist" % config_file
             else:
-                print "File was found in expected location"
+                print("File was found in expected location")
         except IOError:
             return 'ERROR Could not verify the existence of the file %s' % config_file
 
@@ -730,11 +759,11 @@ def testInstanceSettingByName(what, connection, server_instance):
 
         section = profile.config_file_section
         cfg_file_content = ""
-        print "Check if %s section exists in %s" % (section, config_file)
+        print("Check if %s section exists in %s" % (section, config_file))
         try:
             #local_file = test_ssh_connection.fetch_file(config_file)
             cfg_file_content = test_ssh_connection.server_helper.get_file_content(path=config_file)
-        except Exception, exc:
+        except Exception as exc:
             import traceback
             traceback.print_exc()
             return "ERROR "+str(exc)
@@ -745,10 +774,10 @@ def testInstanceSettingByName(what, connection, server_instance):
 
     elif what in ("find_config_file/local", "check_config_path/local", "check_config_section/local"):
         config_file = profile.config_file_path
-        config_file = wb_admin_control.WbAdminControl(profile, connect_sql=False).expand_path_variables(config_file)
-        print "Check if %s can be accessed" % config_file
+        config_file = wb_admin_control.WbAdminControl(profile, None, connect_sql=False).expand_path_variables(config_file)
+        print("Check if %s can be accessed" % config_file)
         if os.path.exists(config_file):
-            print "File was found at the expected location"
+            print("File was found at the expected location")
         else:
             return "ERROR File %s doesn't exist" % config_file
 
@@ -756,9 +785,9 @@ def testInstanceSettingByName(what, connection, server_instance):
             return "OK"
 
         section = profile.config_file_section
-        print "Check if section for instance %s exists in %s" % (section, config_file)
+        print("Check if section for instance %s exists in %s" % (section, config_file))
         if check_if_config_file_has_section(open(config_file, "r"), section):
-            print "[%s] section found in configuration file" % section
+            print("[%s] section found in configuration file" % section)
             return "OK"
         return "ERROR Couldn't find section [%s] in the config file %s" % (section, config_file)
 
@@ -767,29 +796,23 @@ def testInstanceSettingByName(what, connection, server_instance):
 
     elif what == "check_admin_commands":
         path = profile.start_server_cmd
-        cmd_start= None
+        cmd_start = None
         if path.startswith("/"):
             cmd_start = path.split()[0]
-            if not test_ssh_connection.ssh.file_exists(cmd_start):
+            if not test_ssh_connection.ssh.fileExists(cmd_start):
                 return "ERROR %s is invalid" % path
 
         path = profile.stop_server_cmd
         if path.startswith("/"):
             cmd = path.split()[0]
-            if cmd != cmd_start and not test_ssh_connection.ssh.file_exists(cmd):
+            if cmd != cmd_start and not test_ssh_connection.ssh.fileExists(cmd):
                 return "ERROR %s is invalid" % path
 
-        command = profile.check_server_status_cmd
-        print "Checking command '%s'" % command
-        #rc = test_ssh_connection.is_running()
-        rc = test_ssh_connection.server_control.get_status()
-        print "Server detected as %s" % (rc and "running" or "stopped"),
-
         return "OK"
 
     elif what == "check_admin_commands/local":
         path = profile.start_server_cmd
-        cmd_start= None
+        cmd_start = None
         if path.startswith("/"):
             cmd_start = path.split()[0]
             if not os.path.exists(cmd_start):
@@ -801,12 +824,7 @@ def testInstanceSettingByName(what, connection, server_instance):
             if cmd != cmd_start and not os.path.exists(cmd):
                 return "ERROR %s is invalid" % path
 
-        command = profile.check_server_status_cmd
-        print "Checking command '%s'" % command
-        result, rc = local_get_cmd_output(command, Users.CURRENT, None)
-        print "Server detected as %s" % (result and "running" or "stopped")
-
-        return "OK "+(result and "running" or "stopped")
+        return "OK"
 
     return "ERROR bad command"
 
@@ -830,38 +848,41 @@ def testInstanceSettings(server_instance):
 
 ##------------------------------------------------------------------------------------------------------------------------
 
-@ModuleInfo.plugin("wb.admin.open_into", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()])
+@ModuleInfo.plugin("wb.admin.open_into", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()], accessibilityName="Open Into")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor, grt.STRING)
 def openAdminSection(editor, section):
     context = grt.fromgrt(editor.customData["adminContext"])
     if context:
         context.open_into_section(section, True)
     else:
-        log_error(_this_file, "No context found for editor in call to openAdminSection\n")
+        log_error("No context found for editor in call to openAdminSection\n")
 
 
 # Hack to make this plugin only appear if SE modules are available
 try:
     import wba_meb # noqa
-    @ModuleInfo.plugin("wb.admin.open_into_se", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()])
+    @ModuleInfo.plugin("wb.admin.open_into_se", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()], accessibilityName="Open Into")
     @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor, grt.STRING)
     def openAdminSectionSE(editor, section):
         context = grt.fromgrt(editor.customData["adminContext"])
         if context:
             context.open_into_section(section, True)
         else:
-            log_error(_this_file, "No context found for editor in call to openAdminSection\n")
+            log_error("No context found for editor in call to openAdminSection\n")
 except ImportError:
     pass
 
 
-@ModuleInfo.plugin("wb.admin.settings", type="standalone", input=[wbinputs.currentSQLEditor()])
+@ModuleInfo.plugin("wb.admin.settings", type="standalone", input=[wbinputs.currentSQLEditor()], accessibilityName="Settings")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def openConnectionSettings(editor):
     grt.modules.Workbench.showInstanceManagerFor(editor.connection)
+    context = grt.fromgrt(editor.customData["adminContext"])
+    if context:
+        context.refresh_admin_links()
 
 
-@ModuleInfo.plugin("wb.admin.reset_password_cache", type="standalone", input=[wbinputs.currentSQLEditor()])
+@ModuleInfo.plugin("wb.admin.reset_password_cache", type="standalone", input=[wbinputs.currentSQLEditor()], accessibilityName="Reset Password Cache")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def resetPasswordCache(editor):
     context = grt.fromgrt(editor.customData["adminContext"])
@@ -870,7 +891,7 @@ def resetPasswordCache(editor):
         if context.ctrl_be and context.ctrl_be.password_handler:
             context.ctrl_be.password_handler.pwd_store = {}
 
-        for service_type in ["ssh", "sshkey", "file", "service.startstop", "remoteshell"]:
+        for service_type in ["local", "ssh", "sshkey", "file", "service.startstop", "remoteshell"]:
             details = handler.get_password_parameters(service_type)
             if details and details != "UAC":
                 title, service, account = details
