@@ -1,20 +1,25 @@
-/* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/geometry.h"
@@ -31,16 +36,12 @@ static void call_refresh(PhysicalLayerEditor *self)
 }
 
 - (instancetype)initWithModule: (grt::Module*)module
-                    grtManager: (bec::GRTManager *)grtm
                      arguments: (const grt::BaseListRef &)args
 {
-  if (grtm == nil)
-    return nil;
-  
+ 
   self = [super initWithNibName: @"WbPhysicalLayerEditor" bundle: [NSBundle bundleForClass:[self class]]];
   if (self != nil)
   {
-    _grtm = grtm;
     // load GUI. Top level view in the nib is the NSTabView that will be docked to the main window
     [self loadView];
 
@@ -62,12 +63,12 @@ static void call_refresh(PhysicalLayerEditor *self)
 
 - (instancetype)initWithNibName: (NSString *)nibNameOrNil bundle: (NSBundle *)nibBundleOrNil
 {
-  return [self initWithModule: nil grtManager: nil arguments: grt::BaseListRef()];
+  return [self initWithModule: nil arguments: grt::BaseListRef()];
 }
 
 -(instancetype)initWithCoder: (NSCoder *)coder
 {
-  return [self initWithModule: nil grtManager: nil arguments: grt::BaseListRef()];
+  return [self initWithModule: nil arguments: grt::BaseListRef()];
 }
 
 - (void)reinitWithArguments:(const grt::BaseListRef&)args
@@ -76,12 +77,12 @@ static void call_refresh(PhysicalLayerEditor *self)
   delete mBackEnd;
   
   // setup the editor backend with the layer object (args[0])
-  mBackEnd= new LayerEditorBE(_grtm, workbench_physical_LayerRef::cast_from(args[0]));
+  mBackEnd= new LayerEditorBE(workbench_physical_LayerRef::cast_from(args[0]));
   
   // register a callback that will make [self refresh] get called
   // whenever the backend thinks its needed to refresh the UI from the backend data (ie, the
   // edited object was changed from somewhere else in the application)
-  mBackEnd->set_refresh_ui_slot(boost::bind(call_refresh, self));
+  mBackEnd->set_refresh_ui_slot(std::bind(call_refresh, self));
   // update the UI
   [self refresh];
 }
@@ -110,7 +111,7 @@ static void call_refresh(PhysicalLayerEditor *self)
 }
 
 
-- (id)identifier
+- (id)panelId
 {
   // an identifier for this editor (just take the object id)
   return [NSString stringWithCPPString:mBackEnd->get_object().id()];
